import QtQuick 1.0

Item {
    id: dropDown
    width: parent ? parent.width : 100
    height: 45

    property variant value

    property alias icon: selectedIcon.source
    property alias text: selectedText.text    
    property alias title: dialog.title

    property alias delegate: dropDownRepeater.delegate
    property alias model: dropDownRepeater.model
    property alias spacing: dropDownColumn.spacing

    property Item target

    signal shown
    signal hidden

    function show() {
        if (target && dropDownRepeater.model && dropDownRepeater.model.length > 0) {
            dialog.show(target)
        }
    }

    function hide() {
        dialog.hide();
    }

    BorderImage {
        id: name
        source: "../../images/meegotouch-list-background.png";
        anchors.fill: parent
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        border.left: 20; border.top: 20
        border.right: 20; border.bottom: 20
    }

    Item {
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: indicator.left
        anchors.leftMargin: 10
        anchors.rightMargin: 10

        z: 200

        Image {
            id: selectedIcon
            source: ""
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            asynchronous: true
        }

        Label {
            id: selectedText
            font.pixelSize: 22
            color: "#000"
            anchors.left: parent.left
            anchors.leftMargin: 45
            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            elide: Text.ElideRight
        }
    }

    Image {
        id: indicator
        anchors.rightMargin: 5
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        source: "../../images/meegotouch-combobox-indicator.png"
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            dropDown.show();
        }
    }

    PopupNotification {
        id: dialog
        containerHeight: dropDownColumn.height

        onShown: {
            dropDown.shown();
        }

        onHidden: {
            dropDown.hidden();
        }

        Flickable {
            anchors.fill: parent
            contentHeight: dropDownColumn.height

            Column {
                id: dropDownColumn

                anchors.left: parent.left
                anchors.right: parent.right

                Repeater {
                    id: dropDownRepeater
                }
            }
        }
    }

    states: State {
             name: "disabled"
             when: dd.model.length < 3
             PropertyChanges {
                 target: dd
                 opacity: 0.6
             }
             PropertyChanges {
                 target: mouseArea
                 enabled: false
             }
         }
}
