import QtQuick 1.0

BorderImage {
    id: flipElem
    width: 65
    height: 80

    source: "../../images/timeflicker.png"
    border { left: 10; top: 15; right: 10; bottom: 15 }
    horizontalTileMode: BorderImage.Repeat
    verticalTileMode: BorderImage.Repeat

    property alias model: flipView.model
    property alias selectedValue: flipView.selectedValue
    signal selectedValueChanged

    function selectIndex(index) {
        flipView.positionViewAtIndex(index, ListView.Contain);
    }

    Item {
        id: flip
        anchors.fill: parent
        anchors.leftMargin: 1
        anchors.rightMargin: 1
        anchors.topMargin: 8
        anchors.bottomMargin: 8

        DigitElement {
            id: backgroundDigit
            anchors.fill: parent

            property variant model:
                flipView.backward ?
                    (flipView.turnPoint > 0.5 ? flipView.model[flipView.nextIndex] : flipView.model[flipView.prevIndex]) :
                    (flipView.turnPoint <= 0.5 ? flipView.model[flipView.nextIndex] : flipView.model[flipView.prevIndex])

            text: model.text || model
            footer: model.footer || ""
        }

        Rectangle {
            anchors.fill: parent
            color: "#000"
            opacity: flipView.turnPoint > 0.5 ? flipView.turnPoint - 0.5 : 0.5 - flipView.turnPoint
        }

        Item {
            id: upperPart
            clip: true
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.verticalCenter


            transform: Rotation {
                id: upperPartTransform
                // TODO normally it should be       flip.height/2     flip.width/2
                origin.y: flip.height/2; origin.x: 2 * flip.width;
                axis.x: 1; axis.y: 0; axis.z: 0
                angle: flipView.turnPoint > 0.5 ? (-1 + flipView.turnPoint) * 180 : 0
            }

            DigitElement {
                id: upperPartDigit
                property variant model: flipView.model[flipView.currentIndex]

                width: flip.width
                height: flip.height

                text: model.text || model
                footer: model.footer || ""
            }
        }

        Item {
            id: lowerPart
            clip: true
            anchors.top: parent.verticalCenter
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom

            transform: Rotation {
                id: lowerPartTransform                
                // TODO normally it should be       0    flip.width/2
                origin.y: 0; origin.x: 2 * flip.width
                axis.x: 1; axis.y: 0; axis.z: 0
                angle: flipView.turnPoint <= 0.5 ? flipView.turnPoint * 180 : 0
            }

            DigitElement {
                id: lowerPartDigit
                property variant model: flipView.model[flipView.currentIndex]

                width: flip.width
                height: flip.height
                anchors.bottom: parent.bottom
                text: model.text || model
                footer: model.footer || ""
            }
        }
    }

    ListView {
        id: flipView
        anchors.fill: parent

        orientation: ListView.Vertical

        property real turnPoint: (Math.min(Math.max(0, flipView.contentY),flipView.contentHeight-flipView.height)%flipView.height)/flipView.height;

        property int prevIndex: 0
        property int nextIndex: 1

        property bool backward: false

        property variant selectedValue: model[currentIndex].value == null ? model[currentIndex] : model[currentIndex].value

        property int lastIndex: 0

        onSelectedValueChanged: flipElem.selectedValueChanged()

        delegate: Item {
            height: flipView.height;
            width: flipView.width;

            MouseArea {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.bottom: parent.verticalCenter
                onClicked: {
                    flipView.currentIndex = Math.max(flipView.currentIndex - 1, 0);
                }
            }
            MouseArea {
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: parent.verticalCenter
                anchors.bottom: parent.bottom
                onClicked: {
                    flipView.currentIndex = Math.min(flipView.currentIndex + 1, flipView.count - 1);
                }
            }
        }
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.StrictlyEnforceRange

        onCurrentIndexChanged: {
            if (lastIndex > flipView.currentIndex) {
                nextIndex = Math.max(0, flipView.currentIndex - 1);
                prevIndex = Math.min(flipView.count - 1, flipView.currentIndex + 1);
                backward = true;
            } else {
                prevIndex = Math.max(0, flipView.currentIndex - 1);
                nextIndex = Math.min(flipView.count - 1, flipView.currentIndex + 1);
                backward = false;
            }
            //print(lastIndex, " => ", prevIndex, flipView.currentIndex, nextIndex, backward);

            lastIndex = flipView.currentIndex;
        }
    }
}
