import QtQuick 1.0

import com.nokia.pt 1.0

import "styles"

// line information
Item {
    id: item

    height: destination.visible ? destination.height + destination.y : symbol.height

    property variant line

    property alias destinationElement: destination

    property bool showDestination: true
    property int symbolTopPadding: 0

    property int threshold: width / 5

    property bool isShortLayout: label.paintedWidth <= item.threshold

    property QtObject style: LineItemStyle {}

    LineSymbol {
        id: symbol

        y: (showDestination ? (isShortLayout ? Math.min(20, (destination.paintedHeight - symbol.height)) / 2 : 0) : 0) + symbolTopPadding

        height: label.paintedHeight + label.y * 2 - 2
        width: Math.min(label.paintedWidth, hackForPaintedWidth.paintedWidth) + label.x * 2

        color: item.line.lineScheme.color || "#000"
        shape: sanitizeShape(item.line.lineScheme.shape || item.line.transitType.shape, item.line.name)
        outlineColor: item.line.lineScheme.outlineColor

        smooth: item.smooth

        //For fix the Symbian 1 bug in Text:paintedwidth
        Text {
            id: hackForPaintedWidth
            visible: false
            text: label.text
            font:label.font
        }

        Text { // S75
            id: label
            y: 3
            x: symbol.shape === LineScheme.RoundedRect ? 10 : 6
            text: item.line.name
            color: item.line.lineScheme.textColor || "#fff"
            wrapMode: Text.Wrap
            width: item.width
            font: item.style.lineFont
            smooth: item.smooth
        }

        // changes Circles to RoundedRect's (PT-974)
        function sanitizeShape(shape, name) {
            return LineScheme.Circle === shape ? LineScheme.RoundedRect : shape;
        }
    }

    property int textIndent: destination.anchors.leftMargin

    Text { // to foo station
        id: destination
        anchors {
            left: item.left
            leftMargin: isShortLayout ? symbol.width + 8 : 3
            top: isShortLayout ? item.top : symbol.bottom
            right: item.right
        }
        text: item.line.direction
        wrapMode: Text.Wrap
        font: item.style.font
        visible: item.showDestination
        smooth: item.smooth
    }
}
