import QtQuick 1.0

import "styles"

Item {
    id: root

    property bool subItemIndicator: false
    property bool selected: false
    property int contentHeight // - 13 - 13 margin

    property alias paddingItem: paddingItem // Read-only

    property QtObject style: ListItemStyle {}

    Component.onCompleted: style.parent = root

    Item {
        // non-visible item to create a padding boundary that content items can bind to
        id: paddingItem
        anchors {
            fill: parent
            leftMargin: 13
            rightMargin: subItemIndicator ? 25 : 13
            topMargin: 13
            bottomMargin: 13
        }
    }

    signal clicked;

    height: Math.max(style.height - 26, contentHeight) + paddingItem.anchors.topMargin + paddingItem.anchors.bottomMargin
    width: parent ? parent.width : undefined

    Image { // pressed state
        id: pressedImage
        x: 0
        y: 0
        height: parent.height
        width: parent.width
        source: "../../images/list-item-background-pressed-long.png"
        opacity: 0
        enabled: opacity > 0
    }

    Image { // more
        id: moreImage
        anchors {
            right: parent.right
            rightMargin: 12
            verticalCenter: parent.verticalCenter
        }
        visible: subItemIndicator
        source: "../../images/drill_down_arrow_default.png"
    }

    Image { // more highlight
        id: pressedMoreImage
        anchors.fill: moreImage
        source: "../../images/drill_down_arrow_down.png"
        visible: subItemIndicator
        opacity: 0
    }

    Rectangle {
        y: parent.height - 1
        width: parent.width
        height: 1
        color: "#999"
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        enabled: parent.enabled

        onClicked: root.clicked();
    }

    state: enabled ? selected ? "selected" : mouseArea.pressed ? "pressed" : "" : "disabled"

    states: [
        State {
            name: "pressed"
            PropertyChanges { target: pressedImage;  opacity: 1 }
            PropertyChanges { target: pressedMoreImage;  opacity: 1 }
            PropertyChanges { target: moreImage;  opacity: 0 }
        },
        State {
            name: "selected"
            PropertyChanges { target: pressedImage;  opacity: 1 }
            PropertyChanges { target: pressedMoreImage;  opacity: 1 }
            PropertyChanges { target: moreImage;  opacity: 0 }
        },
        State {
            name: "disabled"
            PropertyChanges { target: moreImage;  opacity: 0.4 }
        }
    ]
    transitions: [
        Transition {
            from: "pressed"; to: ""
            NumberAnimation { target: pressedImage; property: "opacity"; duration: 200; easing.type: Easing.InQuad }
            NumberAnimation { target: moreImage; property: "opacity"; duration: 200; easing.type: Easing.InQuad }
            NumberAnimation { target: pressedMoreImage; property: "opacity"; duration: 200; easing.type: Easing.InQuad }
        },
        Transition {
            from: "selected"; to: ""
            NumberAnimation { target: pressedImage; property: "opacity"; duration: 500; easing.type: Easing.OutQuad }
            NumberAnimation { target: moreImage; property: "opacity"; duration: 500; easing.type: Easing.InQuad }
            NumberAnimation { target: pressedMoreImage; property: "opacity"; duration: 500; easing.type: Easing.InQuad }
        }
    ]
}
