import QtQuick 1.0

Rectangle {
    id: dialog
    anchors.fill: parent
    color: "#00000000"
    z: 15000
    visible: false

    signal shown
    signal hidden
    signal cancelled

    property bool isShown: false
    property bool dismissable: true
    property alias title: titleText.text
    default property alias children: contentItems.children
    property int containerHeight: contentItems.children.length > 0 ? contentItems.children[0].height : 100

    function show(target) {
        if (target) {
            dialog.parent = target;
        }
        dialog.state = "shown";
        isShown = true;
        shown();
    }

    function hide() {
        dialog.state = "";
        isShown = false;
        hidden();
    }

    function cancel() {
        hide();
        cancelled();
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            if (dismissable) {
                cancel();
            }
        }
        enabled: dialog.state == "shown"
    }

    BorderImage {
        id: innerDialog

        anchors.left: parent.left
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        anchors.leftMargin: 15
        anchors.rightMargin: 15
        height: Math.min(parent.height - 60, containerHeight + 65)

        opacity: 0.0
        source: "../../images/meegotouch-list-background.png";
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        border.left: 20; border.top: 30
        border.right: 20; border.bottom: 30

        Label {
            id: titleText
            y: 10
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.right: parent.right
            anchors.rightMargin: 35

            color: "#000"
            elide: Text.ElideRight

            font.pixelSize: 22
            font.bold: true
        }

        Image {
            visible: dismissable
            source: "../../images/dd_close.png"
            anchors.right: parent.right
            anchors.rightMargin: 15
            anchors.verticalCenter: titleText.verticalCenter
        }

        Rectangle {
            x: 1
            y: 44
            width: parent.width - 2
            height: 1
            color: "#2464c6"
        }

        Rectangle {
            x: 1
            y: 45
            width: parent.width - 2
            height: 1
            color: "#ccc"
        }

        Item {
            id: contentItems
            anchors.top: parent.top
            anchors.topMargin: 45
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20
            anchors.left: parent.left
            anchors.leftMargin: 1
            anchors.right: parent.right
            anchors.rightMargin: 1
            clip: true
        }
    }

    states: [State {
            name: "shown"
            PropertyChanges {
                target: dialog
                color: "#88000000"
                visible: true
            }
            PropertyChanges {
                target: innerDialog
                opacity: 1.0
            }
        }]

    transitions: Transition {
        to: "shown"
        reversible: true
        SequentialAnimation {
            ColorAnimation { target: dialog; duration: 150; easing.type: Easing.InOutQuad }
            PropertyAnimation { target: innerDialog; property: "opacity"; duration: 150; easing.type: Easing.InOutQuad }
        }
    }
}
