import QtQuick 1.0

Item {
    id: root

    property alias delegate: list.delegate

    property int showingTime: 5000
    property int closingTime: 2000

    function error(msg) {
        model.append({
                         message: msg,
                         iconSource: "error"
                     });
        errorMessage(msg);
    }

    function success(msg) {
        model.append({
                         message: msg,
                         iconSource: "success"
                     });
        successMessage(msg);
    }

    function info(msg) {
        model.append({
                         message: msg,
                         iconSource: "info"
                     });
        infoMessage(msg);
    }

    function custom(msg, type) {
        model.append({
                         message: msg,
                         iconSource: type
                     });
        customMessage(msg, type);
    }

    signal errorMessage(string message)
    signal successMessage(string message)
    signal infoMessage(string message)
    signal customMessage(string message, string type)

    anchors {
        fill: parent
        topMargin: 3
        leftMargin: 8
        rightMargin: 8
        bottomMargin: 5
    }

    ListView {
        id: list
        anchors.fill: parent

        interactive: false
        spacing: 3

        model: ListModel {
            id: model
        }

        delegate: Rectangle {
            id: wrapper
            width: parent.width
            height: Math.max(50, text.paintedHeight + 10)
            radius: 5
            color: "#123"
            border {
                color: "#555"
                width: 1
            }
            Behavior on color { ColorAnimation { duration: 100 } }


            Image {
                id: icon
                anchors {
                    left: parent.left
                    leftMargin: 10
                    verticalCenter: parent.verticalCenter
                }
                source: _getIcon(iconSource) || ""
                visible: !!source

                function _getIcon(iconId) {
                    switch(iconId) {
                        case "error":    return "../../images/toast/error.png"
                        case "success":  return "../../images/toast/success.png"
                        case "info":     return "../../images/toast/info.png"
                    }
                    return iconId
                }
            }

            Text {
                id: text
                anchors {
                    left: icon.visible ? icon.right : parent.left
                    leftMargin: 10
                    right: parent.right
                    rightMargin: 10
                    verticalCenter: parent.verticalCenter
                }
                color: "white"
                text: message
                wrapMode: Text.Wrap
            }

            Timer {
                id: showingTimer
                interval: root.showingTime
                onTriggered: parent.state = "closing"
            }

            Timer {
                id: closingTimer
                interval: root.closingTime
                onTriggered: list.model.remove(index)
            }

            state: "showing" // showing / closing / pinned

            MouseArea {
                anchors.fill: parent
                onClicked: list.model.remove(index)
//                onClicked: {
//                    if ("closing" === parent.state) parent.state = "pinned";
//                    else list.model.remove(index)
//                }
                onPressAndHold: parent.state = "pinned"
            }

            states: [
                State {
                    name: "showing"
                    PropertyChanges { target: showingTimer; running: true }
                },
                State {
                    name: "closing"
                    PropertyChanges { target: closingTimer; running: true }
                    PropertyChanges { target: wrapper; opacity: .2 }
                },
                State {
                    name: "pinned"
                    PropertyChanges { target: wrapper; color: "#224488" }
                }
            ]

            ListView.onAdd: SequentialAnimation {
                PropertyAction { target: wrapper; property: "scale"; value: 0 }
                NumberAnimation { target: wrapper; property: "scale"; to: 1; duration: 250; easing.type: Easing.OutBack }
            }
            ListView.onRemove: SequentialAnimation {
                PropertyAction { target: wrapper; property: "ListView.delayRemove"; value: true }
                NumberAnimation { target: wrapper; property: "opacity"; to: 0; duration: 250; easing.type: Easing.InOutQuad }
                NumberAnimation { target: wrapper; property: "height"; to: 0; duration: 250; easing.type: Easing.InOutQuad }
                PropertyAction { target: wrapper; property: "ListView.delayRemove"; value: false }
            }

            transitions: [
                Transition {
                    to: "closing"
                    PropertyAnimation { target: wrapper; properties: "opacity"; duration: root.closingTime }
                }
            ]
        }
    }
}
