import QtQuick 1.0 // to target S60 5th Edition or Maemo 5

import com.nokia.pt 1.0

Item {
    id: root

    height: 90
    property int iconSpace: 80

    // quick access
    property alias font: standardFont.font
    property alias color: standardStyle.color

    // substyles
    property alias standard: standardStyle
    Item {
        id: standardStyle

        property string color: "#282828"
        property alias font: standardFont.font

        QmlFont {
            id: standardFont
            font {
                pixelSize: 26
                weight: Font.Bold
            }
        }
    }

    property alias subtitle: subTitleStyle
    Item {
        id: subTitleStyle

        property string color: "#666666"
        property alias font: subTitleTextFont.font

        QmlFont {
            id: subTitleTextFont
            font {
                pixelSize: 22
                weight: Font.Light
            }
        }
    }

    state: parent && parent.state || ""

    states: [
        State {
            name: "pressed"
            PropertyChanges { target: standardStyle; color: "#ffffff" }
            PropertyChanges { target: subTitleStyle; color: "#ffffff" }
        },
        State {
            name: "selected"
            PropertyChanges { target: standardStyle; color: "#ffffff" }
            PropertyChanges { target: subTitleStyle; color: "#ffffff" }
        },
        State {
            name: "disabled"
            PropertyChanges { target: standardStyle; color: "#a9a9a9" }
            PropertyChanges { target: subTitleStyle; color: "#a9a9a9" }
        }
    ]

    transitions: [
        Transition {
            from: "pressed"; to: ""
            ColorAnimation { target: standardStyle; property: "color"; duration: 200; easing.type: Easing.InQuad }
            ColorAnimation { target: subTitleStyle; property: "color"; duration: 200; easing.type: Easing.InQuad }
        },
        Transition {
            from: "selected"; to: ""
            ColorAnimation { target: standardStyle; property: "color";  duration: 500; easing.type: Easing.OutSine }
            ColorAnimation { target: subTitleStyle; property: "color";  duration: 500; easing.type: Easing.OutSine }
        }
    ]
}
