import QtQuick 1.0

import "../../qtcomponents"
import "../../components"

import "../ApplicationModel.js" as App

Page {
    id: aboutPage
    objectName: "aboutPage"

    title: qsTrId("qtn_pt_aboutpage_title")

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            btnFeedback.enabled = (App.settings.lastNpsVote || 0) < Date.now() - 86400000; // only show every 24 hours
            app.analytics.logEvent("About");
        }
        if ("Active" === statusStr) {
            btnSupportedRegions.selected = false;
            btnFeedback.selected = false;
            btnThanks.selected = false;
            btnPrivacy.selected = false;
            btnCheckUpdates.selected = false;
        }
    }

    Flickable {
        anchors { fill: parent; leftMargin: 10; rightMargin: 10 }
        contentHeight: Math.max(col.height + col.y, height)

        Column {
            id: col
            anchors { left: parent.left; right: parent.right; }
            spacing: 20
            y: 30

            Column {
                width: parent.width
                Image {
                    id: nokiaLogo
                    anchors { left: parent.left; }
                    source: "../../../images/sources/nokia-logo.png"
                    height: sourceSize.height
                    width: sourceSize.width
                }

                Text {
                    id: appNameAndVersion

                    text: "<b>" + System.appName + "</b> " + System.appVersionFormatted
                    textFormat: Text.RichText
                    width: parent.width
                    wrapMode: Text.Wrap

                    color: "#3d3d3d"
                    font.pixelSize: 28
                }

                Text {
                    id: buildNumber

                    width: parent.width
                    wrapMode: Text.Wrap

                    text: qsTrId("qtn_pt_aboutpage_buildnumber").arg(System.appBuild || "?")
                    visible: System.debugMode

                    color: "#858585"
                    font.pixelSize: 20
                }
            }

            Item {} // spacer

            Label {
                color: "#858585"
                font.pixelSize: 20
                font.letterSpacing: -1
                text: qsTrId("qtn_pt_aboutpage_appdescription")
                wrapMode: Text.WordWrap
                anchors { left: parent.left; right: parent.right; }
            }

            Column {
                anchors { left: parent.left; right: parent.right; leftMargin: -10; rightMargin: -10}
                ListItem { // hack'o'rama for the upper line
                    height: 1
                }

                ListItem {
                    id: btnSupportedRegions
                    objectName: "supportedRegionsBtn"
                    subItemIndicator: true

                    ListItemText {
                        anchors {
                            left: btnSupportedRegions.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        text: qsTrId("qtn_pt_aboutpage_supportedRegions") // Supported Regions
                    }

                    onClicked: {
                        selected = true;
                        pageStack.push(Qt.resolvedUrl("SupportedRegions.qml"))
                    }
                }

                ListItem {
                    id: btnFeedback
                    objectName: "feedbackBtn"
                    subItemIndicator: true

                    ListItemText {
                        anchors {
                            left: btnFeedback.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        enabled: parent.enabled
                        text: qsTrId("qtn_pt_aboutpage_feedback")
                    }

                    onClicked: {
                        selected = true;
                        pageStack.push(Qt.resolvedUrl("Feedback.qml"))
                    }
                }

                ListItem {
                    id: btnPrivacy
                    objectName: "Privacybtn"
                    subItemIndicator: true

                    ListItemText {
                        anchors {
                            left: btnPrivacy.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        text: qsTrId("qtn_pt_privacy_title") // Privacy
                    }

                    onClicked: {
                        selected = true;
                        pageStack.push(Qt.resolvedUrl("AboutPrivacy.qml"))
                    }
                }

                ListItem {
                    id: btnTC
                    objectName: "TCbtn"

                    ListItemText {
                        id: btnTCtext
                        anchors {
                            left: btnTC.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        text: qsTrId("qtn_pt_aboutpage_termsconditions") // Service Terms
                    }

                    onClicked: {
                        pageStack.push(Qt.resolvedUrl("../../components/WebViewPage.qml"), {
                                           url: "http://nokia.mobi/privacy/services/terms/nokia-service",
                                           title: btnTCtext.text
                                       });
                        app.analytics.logEvent("ExternalTermsAndConditions");
                    }
                }

                ListItem {
                    id: btnSupport
                    objectName: "supportBtn"

                    ListItemText {
                        id: btnSupportText
                        anchors {
                            left: btnSupport.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        text: qsTrId("qtn_pt_aboutpage_support") // Support
                    }

                    onClicked: {
                        pageStack.push(Qt.resolvedUrl("../../components/WebViewPage.qml"), {
                                           url: "http://nokia.mobi/apps/publictransport/support",
                                           title: btnSupportText.text
                                       });
                        app.analytics.logEvent("ExternalSupport");
                    }
                }

                ListItem {
                    id: btnThanks
                    objectName: "thanksBtn"
                    subItemIndicator: true

                    ListItemText {
                        anchors {
                            left: btnThanks.paddingItem.left
                            verticalCenter: parent.verticalCenter
                        }
                        text: qsTrId("qtn_pt_aboutpage_noteofthanks") // Note of Thanks
                    }

                    onClicked: {
                        selected = true;
                        pageStack.push(Qt.resolvedUrl("ThanksPage.qml"));
                    }
                }

            }

            Column {
                anchors { left: parent.left; right: parent.right; }
                spacing: 10
                visible: App.source.company.length > 0

                AboutPageSectionHeader {
                    text: qsTrId("qtn_pt_aboutpage_acknowledgements_source") // "with the assistance of"
                }

                Repeater {
                    model: App.source.company

                    delegate: Item {
                        anchors { left: parent.left; right: parent.right; }
                        height: Math.max(sourceIcon.height, sourceSource.paintedHeight) + 10

                        Image {
                            id: sourceIcon

                            source: "../../../images/sources/" + modelData.logo
                            width: Math.min(sourceSize.width, modelData.text ? 80 : 200)
                            height: sourceSize.height * width / sourceSize.width
                            asynchronous: true
                            smooth: true
                        }

                        AboutPageSectionContent {
                            id: sourceSource
                            anchors {
                                top: parent.top
                                bottom: parent.bottom
                                left: sourceIcon.right
                                leftMargin: 20
                                right: parent.right
                            }
                            text: modelData.text
                            verticalAlignment: Text.AlignVCenter
                            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                        }
                    }
                }
            }

            Column {
                anchors { left: parent.left; right: parent.right; }

                AboutPageSectionHeader {
                    text: qsTrId("qtn_pt_aboutpage_acknowledgements_opensource") // "Open Source Software"
                }

                AboutPageSectionContent {
                    text: qsTrId("qtn_pt_aboutpage_acknowledgements_opensource_nokiapt_uses").arg(System.appName) // "%1 uses Nokia Qt, the cross-platform application and UI framework and the Zlib Compression Library written by Jean-Loup Gailly and Mark Adler."
                }
            }

            Column {
                anchors { left: parent.left; right: parent.right; leftMargin: -10; rightMargin: -10}
                ListHeading {
                    id: departuresToFavsHeading
                    visible: System.debugMode

                    ListItemText {
                        anchors.fill: parent.paddingItem
                        text: "Debug stuff..."
                        verticalAlignment: Text.AlignVCenter
                    }
                }

                ListItem {
                    id: btnCheckUpdates
                    objectName: "supportedRegionsBtn"
                    subItemIndicator: true
                    visible: System.debugMode

                    ListItemText {
                        anchors {
                            left: parent.paddingItem.left
                            verticalCenter: parent.paddingItem.verticalCenter
                        }
                        text: "Log"
                    }

                    onClicked: {
                        selected = true;
                        pageStack.push(Qt.resolvedUrl("DebugPage.qml"));
                    }
                }
            }

            Item {
                width: 20
                height: 20
            }
        }
    }
}
