import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents" 1.0
import "../../components" 1.0

import "../ApplicationModel.js" as App

Page {
    objectName: "debugPage"

    Debug {
        id: debug
    }

    ViewHeading {
        id: header
        anchors.top: parent.top
        contentHeight: headerText.height
        ViewHeadingText {
            id: headerText
            anchors {
                left: parent.paddingItem.left;
                right: parent.paddingItem.right;
                verticalCenter: parent.paddingItem.verticalCenter
            }
            text: "Debugging and testing stuff"
        }
    }

    Column {
        id: buttons
        anchors {top: header.bottom; topMargin:  10; left: parent.left; right: parent.right }
        spacing: 10

        ButtonRow {
            width: parent.width
            exclusive: false
            Button {
                text: "Check for Update"

                onClicked: {
                    Updater.checkForUpdate(true);
                    pageStack.pop(app);
                }
            }

            Button {
                text: "Clear settings"

                onClicked: {
                    App.favorites.clear();
                    App.history.clear();
                    if (App.ticketing) {
                        App.ticketing.clear();
                    }
                    App.settings = {};
                    App.saveSettings();
                }
            }

            Button {
                text: "Clear ticketing"
                visible: Ticket.ticketingAvailable

                onClicked: App.ticketing.clear()
            }
            Button {
                text: "info"
                onClicked: app.toast.info("This is a notification");
            }
            Button {
                text: "error"
                onClicked: app.toast.error("Oooops, an error occured :(");
            }
        }
    }

    ListView {
        id: debugText
        anchors {top: buttons.bottom; topMargin:  10; left: parent.left; right: parent.right; bottom: parent.bottom }
        cacheBuffer: 30
        clip: true
        model: debug.logText.split("\n").reverse().slice(0, 1000).map(function(line) {
                                                                          return {
                                                                              type: { "!" : "error", "*" : "warning" }[line[0]] || "info",
                                                                              color: { "!" : "red", "*" : "blue" }[line[0]] || "black",
                                                                              time: line.substring(2,11).trim(),
                                                                              message: line.substr(14)
                                                                          }
                                                                      })
        delegate: Item {
            height: text.height
            Image {
                y: 2
                x: 2
                source: modelData.message ? ("../../../images/debug/" + modelData.type + ".png") : ""
            }
            Text {
                y: 1
                x: 20
                width: 55
                text: modelData.time
                horizontalAlignment: Text.AlignRight
                font.pixelSize: 14
            }
            Text {
                id: text
                y: 1
                x: 80
                wrapMode: Text.WrapAnywhere
                width: parent.parent.width - x
                text: modelData.message
                font.pixelSize: 14
                color: modelData.color
            }
            Rectangle {
                y: text.height
                height: 1
                width: parent.parent.width
                color: "#999"
            }
        }
    }
}
