import QtQuick 1.0

import com.nokia.pt 1.0 // needed by Feedback.js

import "../../qtcomponents" 1.0
import "../../components"
import "../../components/styles"
import ".."

import "../ApplicationModel.js" as App
import "Feedback.js" as Logic

Page {
    id: feedbackScene
    objectName: "feedbackPage"

    property int oldRating

    title: qsTrId("qtn_pt_feedback_title")

    property bool busy: false

    onStatusStrChanged: {
        if (statusStr === "Activating") {
            app.analytics.logEvent("NPS");
        }
    }

    RichTextStyle {
        id: style
    }

    Flickable {
        anchors { fill: parent; topMargin: 10 }
        contentHeight: Math.max(column.height + 10, height)

        Column {
            id: column
            spacing: 15
            anchors {
                left: parent.left;
                leftMargin: 10;
                right: parent.right;
                rightMargin: 10
            }

            Text {
                text: qsTrId("qtn_pt_feedback_recommend_app").arg(System.appName);
                font: style.font
                wrapMode: Text.WordWrap;
                width: parent.width;
            }

            Item {
                height: rateScale.height + Math.max(lowScaleText.height, highScaleText.height)
                width: parent.width
                FeedbackScale {
                    id: rateScale
                    enabled: !feedbackScene.busy
                    height: 43
                    numRatings: 11
                    width: parent.width
                }
                Text {
                    id: lowScaleText;
                    anchors {
                        left: System.rightToLeft ? undefined : rateScale.left
                        right : System.rightToLeft ? rateScale.right : undefined
                        top: rateScale.bottom
                        topMargin: 3
                    }
                    horizontalAlignment: System.rightToLeft ? Text.AlignRight : Text.AlignLeft
                    width: parent.width / 2.1
                    wrapMode: Text.Wrap
                    font.pixelSize: 16
                    text: qsTrId("qtn_pt_feedback_negative"); // Not at all likely
                }
                Text {
                    id: highScaleText
                    anchors {
                        left: System.rightToLeft ? rateScale.left : undefined
                        right: System.rightToLeft ? undefined : rateScale.right
                        top: rateScale.bottom
                        topMargin: 3
                    }
                    horizontalAlignment: System.rightToLeft ? Text.AlignLeft : Text.AlignRight
                    width: parent.width / 2.1
                    wrapMode: Text.Wrap
                    font.pixelSize: 16
                    text: qsTrId("qtn_pt_feedback_positive"); // Extremely likely
                }
            }

            Text {
                text: qsTrId("qtn_pt_feedback_text")
                font: style.font
                wrapMode: Text.Wrap
                width: parent.width
            }

            TextArea {
                id: commentInput
                enabled: !feedbackScene.busy
                height: 77
                width: parent.width
                placeholderText: qsTrId("qtn_pt_feedback_text_placeholder")
            }

            Text {
                text: qsTrId("qtn_pt_feedback_contact")
                font: style.font
                wrapMode: Text.Wrap
                width: parent.width
            }

            TextField {
                id: emailInput
                enabled: !feedbackScene.busy
                width: parent.width
                placeholderText: qsTrId("qtn_pt_feedback_contact_placeholder")
                validator: RegExpOrEmptyValidator { // email validation
                    regExp: /^.+@[^\.].*\.[a-z]{2,}$/
                }
            }

            RichText {
                width: parent.width

                text: qsTrId("qtn_pt_feedback_privacy")
                        .arg("http://nokia.mobi/privacy/policy")

                style: style

                onLinkActivated: {
                    pageStack.push(Qt.resolvedUrl("../../components/WebViewPage.qml"), {
                                       url: link
                                   });
                    app.analytics.logEvent("ExternalPrivacy");
                }
            }

            Item {
                height: 150
                width: parent.width
            }
        }
    }

    tools: ToolBarLayout {

        BackToolButton {}

        ToolIcon {
            objectName: "okBtn"
            iconId: "toolbar-done"
            enabled: !feedbackScene.busy
            onClicked: {
                if (rateScale.rating === -1) {
                    app.displayMessage("error", qsTrId("qtn_pt_feedback_error_no_rating")); // Please select a rating
                } else if (emailInput.errorHighlight) {
                    app.displayMessage("error", qsTrId("qtn_pt_feedback_contact_placeholder")); //
                } else {
                    Logic.submitVote(rateScale.rating, commentInput.text, emailInput.text);
                }
            }
        }
    }
}
