import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import "../../components/styles"
import ".."

import "../ApplicationModel.js" as App


Page {
    id: supportedRegionsPage
    objectName: "supportedRegionsPage"

    title: qsTrId("qtn_pt_supportedRegions_title")

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("SupportedRegions");
        }
    }

    // Do some sorting
    XmlListModel {
        id: xmlModel
        source: "../../../packages/SupportedRegions.xml"
        query: "/SupportedRegionsInfo/region"
        XmlRole { name: "region"; query: "name/string()" }
        XmlRole { name: "systems"; query: "systems/string()" }
        onStatusChanged: {
            if (XmlListModel.Ready !== status) return;
            regionListView.model.clear();
            for (var i=0, arr=[], item; (item = xmlModel.get(i)); i++) { arr.push(item); }
            arr .sort(function(a, b) {
                          return String.prototype.localeCompare.call(a.region, b.region);
                      })
                .forEach(function(item) {
                            regionListView.model.append(item);
                        });
        }
    }

    ListItemStyle {
        id: listItemStyle
    }

    ListView {
        id: regionListView
        anchors.fill: parent

        model : ListModel {}

        spacing: 10

        header: Item {
            height: headerBar.height + 12
            width: parent.width
            ViewHeading {
                id: headerBar
                contentHeight: titleText.height
                ViewHeadingText {
                    id: titleText
                    anchors {
                        left: parent.paddingItem.left;
                        right: parent.paddingItem.right;
                        verticalCenter: parent.paddingItem.verticalCenter
                    }
                    text: qsTrId("qtn_pt_supportedRegions_header_nosimplerouting")
                }
            }
        }

        footer: Item { // margin element
            width: parent.width
            height: 20
        }

        delegate: Item {
            id: listItem
            height: regionTexts.height
            width: parent ? parent.width : 100

            Column {
                id: regionTexts
                anchors.left: parent.left
                anchors.leftMargin: 12
                anchors.right: parent.right
                anchors.rightMargin: 12
                anchors.verticalCenter: parent.verticalCenter
                spacing: 5

                ListItemText {
                    style: listItemStyle
                    anchors { left: parent.left; right: parent.right }
                    text: region
                    wrapMode: Text.WordWrap
                    elide: Text.ElideNone
                }

                ListItemText {
                    style: listItemStyle
                    role: "subTitle"
                    anchors { left: parent.left; right: parent.right }
                    text: systems
                    wrapMode: Text.WordWrap
                    elide: Text.ElideNone
                }
            }
        }
    }
}
