import QtQuick 1.0

import "../../qtcomponents"
import "../ApplicationModel.js" as App

Page {
    id: page
    title: qsTrId("qtn_pt_aboutpage_noteofthanks")

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("Thanks");
        }
    }

    property Item listFooter;

    ListModel {
        id: model

        Component.onCompleted: {
            [{
                team: "The Team",
                names: ["Andreas G.", "Manuel", "Torsten", "Sascha", "Florentina", "Juan", "Wael", "Elke", "Justus", "Katharina", "Thomas", "Lejla", "Jens", "Anne-Gaëlle", "Andreas H.", "Bilal", "Giuseppe", "Peter", "David", "Leonard", "Dong Mei", "Dennis", "Marko", "Mikko", "Steph", "Phani", "Sandeep", "Jerome", "Jan-Erik", "Jukki"]
                   .sort()
            }, {
                team: "App Labs Team",
                names: ["Akemi", "Darryl", "Henning", "Henrik"]
                   .sort()
            }, {
                team: "Berlin Testing",
                names: ["Stephan", "David", "Anna", "Carolina"]
                   .sort()
            }, {
                team: "Content Team",
                names: ["Carolina", "Huib", "Jeremy", "Joris", "John", "Leo", "Rob", "Simon", "Zdenka", "Josef", "Paul", "Kingston", "Dilip", "Trevor"]
                   .sort()
            }, {
                team: "SoLo Team",
                names: ["Isabel", "Niina", "Shrikant", "Uwa"]
                   .sort()
            }, {
                team: "Qt and Qt Creator",
                names: ["Christian", "Daniel"]
                   .sort()
            }, {
                team: "MOS Enablers",
                names: ["Anthony", "Dragutin", "Giovanni", "Ionel", "Renata", "Roland", "Stefano", "Dominic", "Michal"]
                   .sort()
            }, {
                team: "Other contributions",
                names: ["Oshie", "Erol"]
                   .sort()
            }]
                .reduce(function(a, b) {
                        return a.concat(b.names.map(function(name) {
                                return {
                                    team: b.team,
                                    name: name
                                }
                            }));
                    }, [])
                .forEach(function(data) {
                        model.append(data);
                    });
        }
    }

    Timer {
        id: timer
        running: true
        interval: 30
        repeat: true
        onTriggered: {
            list.contentY++;
            if (list.contentY > listFooter.y + 100) {
                timer.running = false;
                pageStack.pop();
            }
        }
    }

    ListView {
        onMovingChanged: {
            timer.running = !moving
        }

        id: list
        anchors.fill: parent
        header: Item {
            height: app.portrait ? 500 : 300
            width: 1
        }

        footer: Item {
            id: footer
            height: page.height
            Component.onCompleted: listFooter = footer
        }

        spacing: 10

        model: model

        section.property: "team"
        section.criteria: ViewSection.FullString
        section.delegate: Item {
            property bool shown: y > 0 && y < list.contentY + list.height - height
            height: 80
            width: parent.width
            Text {
                id: text
                y: 35
                text: section
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }
            Rectangle {
                anchors {
                    top: text.bottom
                    topMargin: 2
                    horizontalCenter: text.horizontalCenter
                }
                height: 1
                width: text.paintedWidth + 50
                color: "#888"
            }
        }

        delegate: Text {
            property bool shown: y > 0 && y < list.contentY + list.height - height
            width: parent.width
            text: name
            horizontalAlignment: Text.AlignHCenter
            opacity: shown ? 1 : 0
            Behavior on opacity { NumberAnimation { duration: 750;  } }
            x: shown ? 0 : (index % 2 ? 25 : -25)
            Behavior on x { NumberAnimation { duration: 500; easing.type: "OutQuad" } }
        }
    }
}
