import QtQuick 1.0

import "../ApplicationModel.js" as App

Item {
    property variant analytics
    property bool disabled: false

    signal analyticsLoaded

    function logEvent(message, object) {
        if (!disabled && loader.item) {
            loader.item.logEvent(message, object);
        }
    }
    function closeSession() {
        if (!disabled && loader.item) {
            loader.item.closeSession();
        }
    }

    Loader {
        id: loader

        onStatusChanged: {
            if (status === Loader.Error) {
                if (loader.source !== "AnalyticsForDesktop.qml") {
                    console.warn("could not load analytics, trying desktop wrapper");
                    loader.source = "AnalyticsForDesktop.qml";
                } else {
                    console.error("All analytics failed")
                }
            } else if (status === Loader.Ready) {
                analyticsLoaded();
            }
        }
    }

    onDisabledChanged: __update()

    Component.onCompleted: {
        disabled = !!App.settings.analyticsDisabled;
        __update();
    }

    function __update() {
        if (disabled) {
            loader.source = "AnalyticsDisabled.qml";
        } else {
            loader.source = "AnalyticsForMobile.qml";
        }
    }
}
