import QtQuick 1.0

import "../qtcomponents"
import "../components"

import "ApplicationModel.js" as App

Rectangle {
    id: autocompletions

    property QtObject input
    property bool inputSelected: false
    property QtObject listArea
    property alias listModel: listView.model
    property alias delegate: listView.delegate

    color: "#f1f1f1"
    signal listScrolled
    signal retryClicked

    states: State {
        name: "visible"
        when: inputSelected

        ParentChange {
            target: autocompletions
            parent: listArea
        }
        PropertyChanges {
            target: autocompletions
            visible: true
        }
    }

    property bool isLoading: undefined === listModel
    property bool isEmptyResult: !!(inputSelected && listModel && listModel.length === 0)

    ListView {
        id: listView
        anchors.fill: parent
        state: ""

        model: []
        opacity: model ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 250 } }

        delegate: LocationItem {
            model: modelData
            highlightText: input.text

            onClicked: {
                if (modelData.source.indexOf("currentValue") == -1) {
                    setValue(modelData, index);
                } else {
                    valueChanged();
                }

                selected = false;
                //app.forceActiveFocus();
            }

            onFavoriteButtonClicked: {
                if (model.favorite) {
                    App.favorites.remove(model, listView);
                    app.analytics.logEvent("RemoveFavorite");
                } else {
                    model.parent = input; // Fix to prevent GC favorite in EditPage
                    pageStack.push(Qt.resolvedUrl("./EditFavoritePage.qml"), { favorite: model });
                    app.forceActiveFocus();
                }
            }
        }

        onMovementStarted: {
            autocompletions.listScrolled();
        }
    }

    ListItem {
        anchors {
            top: parent.top
            left: parent.left
            right: parent.right
        }
        contentHeight: msg.paintedHeight
        opacity: isEmptyResult ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 350 } }

        ListItemText {
            id: msg
            anchors {
                left: parent.paddingItem.left
                right: parent.paddingItem.right
                verticalCenter: parent.verticalCenter
            }
            text: qsTrId("qtn_pt_autocompletion_retry_search")
            wrapMode: Text.Wrap
            horizontalAlignment: Text.AlignHCenter
        }

        onClicked: {
            autocompletions.retryClicked();
        }
    }

    BusyIndicator {
        anchors {
            top: parent.top
            topMargin: 18
            horizontalCenter: parent.horizontalCenter
        }
        opacity: isLoading ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 250 } }
        running: opacity > 0
        width: 32
    }

    ScrollIndicator {
        scrollArea: listView
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.right: parent.right
    }
}
