import QtQuick 1.0

import "../qtcomponents"
import "../components"

import "ApplicationModel.js" as App

Page {
    id: editFavoritesPage
    objectName: "editFavoritePage"

    property QtObject favorite

    property bool canAddToStartup: favorite ? App.source.supportsAddAsWidget(favorite) : false

    property string favoriteDefaultName: favorite ? favorite.favoriteName || favorite.displayName || favorite.address.asOneLine : ""

    title: qsTrId("qtn_pt_editfavorite_title")

    onStatusStrChanged: {
        if (statusStr === "Active") {
            App.selectedFavorite = favorite;
            favNameInput.cursorPosition = 0;
        }
    }

    Flickable {
        anchors { fill: parent; margins: 20 }
        contentHeight: content.height + 50

        Column {
            id: content
            spacing: 20
            width: parent.width

            Text {
                width: parent.width
                font {
                    pixelSize: 24;
                    bold: true;
                }
                text: qsTrId("qtn_pt_editfavorite_caption")
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }

            Text {
                width: parent.width
                font.pixelSize: 20
                text: qsTrId("qtn_pt_editfavorite_namefield_label") + ":"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }

            TextField {
                id: favNameInput

                anchors.left: parent.left
                anchors.leftMargin: 5
                anchors.right: parent.right
                anchors.rightMargin: 5

                selected: true
                text: favoriteDefaultName
            }

            Item {
                width: parent.width
                height: 125

                TextCheckBox {
                    id: startupScreenCheckBox
                    anchors {
                        top: parent.top
                        left: parent.left
                        leftMargin: 3
                        right: parent.right
                    }
                    enabled: canAddToStartup
                    opacity: canAddToStartup ? 1.0 : 0.2
                    checked: favorite ? (!!favorite.showOnStartup) : false
                    text: qsTrId("qtn_pt_editfavorite_showHomeScreen")
                }

                Label {
                    id: infoLabel
                    anchors {
                        top: startupScreenCheckBox.bottom
                        left: parent.left
                        leftMargin: 56
                        right: parent.right
                    }
                    font.pixelSize: 16
                    opacity: canAddToStartup ? 1.0 : 0.2
                    color: "#888"
                    wrapMode: Text.WordWrap
                    text: qsTrId("qtn_pt_editfavorite_helpText").arg(System.appName)
                }

                Button {
                    id: createBtn
                    y: app.inPortrait ? 0 : -20
                    anchors {
                        top: infoLabel.bottom
                        topMargin: app.inPortrait ? 40 : 10
                        left: parent.left
                        leftMargin:  app.inPortrait ? 10 : 56
                        right: parent.right
                        rightMargin:  app.inPortrait ? 10 : 56
                    }
                    text: qsTrId("qtn_pt_editfavorite_create")

                    onClicked: {
                        var renamed = favoriteDefaultName !== favNameInput.text;
                        App.favorites.add(favorite, favNameInput.text, startupScreenCheckBox.checked);
                        favorite = null;
                        app.analytics.logEvent("SaveAsFavorite", {
                            toHome: startupScreenCheckBox.checked,
                            renamed: renamed
                        });
                        if (startupScreenCheckBox.checked) {
                            //pop null brings you to the top of the stack (ie the home screen) which is
                            //the desired behavior in this case.
                            pageStack.pop(null);
                        } else {
                            pageStack.pop();
                        }
                    }
                }
            }
        }
    }
}
