import QtQuick 1.0

import "../qtcomponents"
import "../components"

Item {
    property alias text: label.text
    property alias icon: icon.source
    property alias retryButton: retryButtonItem.visible
    property alias regionsButton: regionsButtonItem.visible
    property alias font: label.font
    property bool portrait: app.inPortrait

    height: _usedHeight

    signal retryClicked

    visible: false

    property int __spacing: Math.max(Math.min(18, (parent.parent.height - _usedHeight) / 5), 0)

    Image {
        id: icon
        anchors {
            left: parent.left
            top: parent.top
            leftMargin: portrait ? (parent.width - icon.width) / 2 : 60
        }
    }

    Label {
        id: label
        anchors {
            left: portrait ? parent.left : icon.right;
            right: parent.right;
            top: portrait ? icon.bottom : parent.top;
            topMargin: portrait ? __spacing : 0
            leftMargin: 20;
            rightMargin: 20
        }
        color: "#888"
        font.pixelSize: portrait ? 24: 20
        style: Text.Raised
        styleColor: "white"
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
    }

    Item {
        id: buttonContainer
        anchors {
            top: label.bottom;
            topMargin: portrait ? 2 * __spacing : __spacing;
            left: label.left;
            right: label.right;
            leftMargin: 20;
            rightMargin: 20
        }
        height: (retryButtonItem.visible || regionsButtonItem.visible) ? retryButtonItem.height : 0

        Button {
            id: retryButtonItem
            anchors { top:  parent.top; horizontalCenter: parent.horizontalCenter }

            width: 240
            text: qsTrId("qtn_pt_routingerror_retry")
            visible: false

            onClicked: {
                parent.parent.retryClicked();
            }
        }

        Button {
            id: regionsButtonItem
            anchors.fill: retryButtonItem

            width: 240
            text: qsTrId("qtn_pt_routingerror_showregions")
            visible: false

            onClicked: {
                pageStack.push(Qt.resolvedUrl("About/SupportedRegions.qml"));
            }
        }
    }

    property int _usedHeight:
        portrait ? (icon.height + label.height + buttonContainer.height) : Math.max(icon.height, label.height + buttonContainer.height)
}
