import QtQuick 1.0
import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"

import "../ApplicationModel.js" as App

Repeater {
    id: list

    property bool active: false
    property bool favoritesExisting: false

    property bool _updateNeeded: true;

    function clearSelection() {
        if (_selectedItem) {
            _selectedItem.selected = false;
            _selectedItem = undefined;
        }
    }
    property variant _selectedItem

    onActiveChanged: {
        if (active) {
            if (_updateNeeded) {
                __update(false);
            }
        } else {
            App.queue.clear();
        }
    }

    function refresh() {
        __update(true);
    }

    function __update(invalidateCache) {
        App.queue.add(function(next, canceller) {
            // before we load favorites, we insert a wait for valid position as first queue element
            if (App.currentPosition.notAvailable) {
                var trigger = function() {
                    App.currentPosition.positionChanged.disconnect(trigger);
                    next();
                }
                App.currentPosition.positionChanged.connect(trigger);
                canceller(function() { // register canceller
                    App.currentPosition.positionChanged.disconnect(trigger);
                });
            } else {
                next();
            }
        });
        if (invalidateCache) {
            App._homescreen = {};
        }
        model = []; // reset the model
        model = App.favorites.get(true);
        favoritesExisting = !!model.length;
        _updateNeeded = false;
    }

    function x(sticky) {
        if (sticky) _updateNeeded = true;
    }

    Component.onCompleted: {
        App._homescreen = {};
        App.favorites.added.connect(x);
        App.favorites.removed.connect(x);
    }

    property int openRequests: 0
    onOpenRequestsChanged: {
        if (!openRequests) {
            openRequests = 1000000; // disable end of loading event because of later added favs
            app.analytics.logEvent("HomeFavoritesLoaded", {
                appTime: Stats.uptime(),
                numFavorites: App.favorites.get(true).length
            });
        }
    }

    delegate: FavoritesListItem {
        id: item

        title: modelData.displayName

        onConnectionClicked: /* function(index, listItem) */ {
            var page = pageStack.push(Qt.resolvedUrl("../RoutePlanner/JourneyDetailsPage.qml"));
            page.showDetails(App.currentPosition.location, modelData, model, index);
            _selectedItem = listItem;
            listItem.selected = true;
        }

        Component.onCompleted: {
            var cache = App._homescreen[modelData.getKey()];
            if (cache) {
                item.state = "loading"; // needed for transition
                item.state = cache.state;
                item.model = cache.model;
                return;
            }

            // GPS is handled in a queue entry before
            openRequests++;
            App.queue.add(function(next, canceller) {
                openRequests--;
                item.state = "loading";

                if (App.computeDistance(App.currentPosition.location, modelData) < 200) {
                    item.state = "alreadyThere";
                    next();
                    return;
                }

                var req = App.source.queryConnections(App.currentPosition.location, modelData, new Date(), 0, false, null, 5);
                req.finished.connect(function(error, result) {
                    if (error === QueryResult.NoError) {
                        item.model = result.connections.filter(function(conn) { return conn.timetableBased; });
                        item.state = "ready";
                    } else {
                        item.state = "error";
                    }
                    // update cache
                    App._homescreen[modelData.getKey()] = {
                        state: item.state,
                        model: item.model
                    }
                    next();
                });
                canceller(req.cancel);
            });
        }
    }
}
