import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import "../ApplicationModel.js" as App

Item {
    id: item

    property variant title
    property variant model
    signal connectionClicked(int index, variant listItem)

    height: 75
    width: list.width

    state: "fetchingPosition"

    function calcFlickableWidth(model) {
        var totalWidth = destinationText.width + separator.width;
        if (model) {
            totalWidth += model.length * 92;
            totalWidth += 10; // leave some space on the right to show all items
        }
        return totalWidth;
    }

    Flickable {
        id: flicker
        width: parent.width
        height: item.height
        flickableDirection: Flickable.HorizontalFlick
        contentWidth: Math.max(item.width, calcFlickableWidth(model))
        clip: true
        Text {
            id: destinationText
            anchors {
                left: parent.left
                leftMargin: 15 + Math.min(0, flicker.contentX)
                verticalCenter: parent.verticalCenter
            }
            width: (App.app.landscape ? 200 : 98) - Math.min(0, flicker.contentX * 1.5)
            text: title
            elide: Text.ElideRight
        }

        Image {
            id: separator
            source: "../../../images/list-separator-arrow.png"
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: destinationText.right
            }
        }

        Text {
            id: statusText
            anchors {
                left: separator.right
                leftMargin: 8
                right:  parent.right
                rightMargin: 12
                verticalCenter: parent.verticalCenter
            }
            opacity: 0
            Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.InOutQuad } }
            font.pixelSize: 22
            horizontalAlignment: Text.AlignHCenter
            color: "#b5b5b5"
            wrapMode: Text.Wrap
        }

        SpinningImage {
            id: loadingImage
            anchors {
                left: separator.right
                leftMargin: App.app.landscape ? 180 : 100
                verticalCenter: parent.verticalCenter
            }
            running: true
            opacity: 0
            Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.InOutQuad } }
            height: 24
            width: 24
            source: "../../../images/categories/position_searching.png"
        }

        Row {
            id: details
            anchors {
                left: separator.right
            }
            opacity: 0
            Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.InOutQuad } }
            Repeater {
                model: item.model
                delegate: FavoritesListItemDetails {
                    id: detailsItem
                    height: flicker.height
                    model: modelData
                    isLastItem: (item.model.length === (index + 1))
                    onClicked: connectionClicked(index, detailsItem)
                }
            }
        }
    }

    Image {
        id: gradientImage
        visible: !flicker.atXEnd
        anchors {
            top: parent.top
            right: parent.right
            bottom: parent.bottom
            bottomMargin: 1
        }
        source:  "../../../images/more-departures-gradient.png"
    }

    Rectangle {
        y: parent.height - 1
        width: parent.width
        height: 1
        color: "#999"
    }

    states: [
        State {
            name: "ready"
            PropertyChanges { target: details; opacity: 1 }
        },
        State {
            name: "loading"
            PropertyChanges { target: loadingImage; opacity: 1 }
        },
        State {
            name: "fetchingPosition"
            PropertyChanges { target: loadingImage; opacity: 1; slow: true }
        },
        State {
            name: "alreadyThere"
            PropertyChanges { target: statusText; opacity: 1; text: qsTrId("qtn_pt_favoritedestinationitem_alreadythere") }
        },
        State {
            name: "error"
            PropertyChanges { target: statusText; opacity: 1; text: qsTrId("qtn_pt_favoritedestinationitem_unavailable") }
        }
    ]

}
