import QtQuick 1.0

import "../../qtcomponents"
import "../../components"

ListItem {
    id: item

    property variant model: modelData
    property bool isLastItem: false

    anchors.rightMargin: 1
    width: 92

    Column {
        anchors.centerIn: parent
        spacing: 2

        DateTime {
            anchors.horizontalCenter: parent.horizontalCenter
            datetime: model.startTime
            format: "time"
            color: item.style.color
            font {
                pixelSize: 20
                bold: true
                letterSpacing: -1
            }
        }

        DateTime {
            anchors.horizontalCenter: parent.horizontalCenter
            datetime: model.duration
            format: "duration"
            color: item.style.color
            font {
                pixelSize: 14
                letterSpacing: -1
            }
        }

        Row {
            anchors.horizontalCenter: parent.horizontalCenter
            height: 17
            spacing: 3

            Repeater {
                model: modelData.steps.filter(function(step, i) { return !(!step.line || step.line.isWalk && i !==0) }).slice(0, 6)
                delegate: Item { // placeholder for keeping the space in row for invisible elements
                    width: 12
                    height: 12
                    Image {
                        width: 12
                        height: 12
                        opacity: Image.Ready === status ? 1 : 0
                        asynchronous: true
                        source: modelData.line.isWalk ? "../../../packages/__default__/images/type-walk-12px.png" : modelData.line.lineScheme.iconUri(12)
                        Behavior on opacity { NumberAnimation { duration: 500 } }
                    }
                }
            }
        }

    }

    Image {
        id: separator
        source: "../../../images/list-seperator-light.png"
        visible: !isLastItem
        anchors {
            verticalCenter: parent.verticalCenter
            right: parent.right
            rightMargin: -1
        }
    }
}
