import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Page {
    id: homePage
    objectName: "landingPage"

    title: "" //qsTrId("Application short caption")

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("Home");
        } else if (statusStr === "Active" && App.convertedFavoriteRoutes) {
            favoriteRoutesConvertedNotification.show();
            App.convertedFavoriteRoutes = false;
        }
        if ("Active" === statusStr) {
            routePlannerItem.selected = false;
            departuresItem.selected = false;
            favorites.clearSelection();
        }
    }

    tools: ToolBarLayout {
        BackToolButton {}

        ToolIcon {
            objectName: "refreshBtn"
            iconId: "toolbar-refresh"
            visible: (favorites.model && favorites.model.length > 0) || false
            onClicked: favorites.refresh();
        }

        ToolIcon {
            objectName: "infoBtn"
            iconSource: "../../../images/toolbar/information_userguide.png"

            onClicked: pageStack.push(Qt.resolvedUrl("../About/AboutPage.qml"));
        }
    }

    UpdateNotification {
        id: updateNotification
        anchors.fill:  parent
    }

    Loader {
        id: favoriteRoutesConvertedNotification
        anchors.fill: parent

        function show() {
            if (status === Loader.Null) {
                favoriteRoutesConvertedNotification.source = Qt.resolvedUrl("FavoriteRoutesConvertedNotification.qml");
                if (status === Loader.Ready) {
                    favoriteRoutesConvertedNotification.item.show(homePage);
                }
            }
        }
    }

    PageCache {
        id: routePlannerPage
        uri: Qt.resolvedUrl("../RoutePlanner/RoutePlannerPage.qml")
    }

    Flickable {
        anchors.fill: parent
        contentHeight: col.height

        Column {
            id: col
            width: parent.width

            ViewHeading {
                id: header
                contentHeight: Math.max(icon.height, appName.height)
                brightBackground: false

                Image {
                    id: icon
                    anchors {
                        left: parent.paddingItem.left
                        verticalCenter: parent.verticalCenter
                    }
                    fillMode: Image.PreserveAspectFit
                    height: 60
                    smooth: true
                    source: "../../../images/NokiaPT.png"
                    width: 60
                }

                ViewHeadingText {
                    id: appName
                    anchors {
                        left: icon.right
                        leftMargin: 10
                        right: parent.paddingItem.right
                        verticalCenter: parent.verticalCenter
                    }
                    text: System.appName
                }
            }

            // Route Planner Button
            ListItem {
                id: routePlannerItem
                objectName: "routePlanner"

                subItemIndicator: true

                ListItemText {
                    anchors {
                        fill: parent.paddingItem
                        leftMargin: 15
                        rightMargin: 15
                    }
                    text: qsTrId("qtn_pt_homepage_routeplanner")
                    verticalAlignment: Text.AlignVCenter
                }

                onClicked: {
                    selected = true;
                    pageStack.push(routePlannerPage);
                }
            }

            // Nearby Button
            ListItem {
                id: departuresItem
                objectName: "nearby"

                subItemIndicator: true

                ListItemText {
                    anchors {
                        fill: parent.paddingItem
                        leftMargin: 15
                        rightMargin: 15
                    }
                    text: qsTrId("qtn_pt_homepage_departures")
                    verticalAlignment: Text.AlignVCenter
                }

                onClicked: {
                    selected = true;
                    pageStack.push(Qt.resolvedUrl("../Nearby/NearbyPage.qml"))
                }
            }

            // Ticketing Button
            ListItem {
                id: ticketingItem
                objectName: "ticketing"

                visible: Ticket.available && !Ticket.setupCompleted

                subItemIndicator: true

                ListItemText {
                    anchors {
                        fill: parent.paddingItem
                        leftMargin: 15
                        rightMargin: 15
                    }
                    text: "Ticketing" // TODO: I18N!
                    verticalAlignment: Text.AlignVCenter
                }

                onClicked: pageStack.push(Qt.resolvedUrl("../Ticketing/Welcome.qml"));
            }

            ListItem {
                id: checkinHistoryItem
                objectName: "checkinHistory"

                visible: Ticket.available && Ticket.setupCompleted

                subItemIndicator: true

                ListItemText {
                    anchors {
                        fill: parent.paddingItem
                        leftMargin: 15
                        rightMargin: 15
                    }
                    text: "Tap history" // TODO: I18N!
                    verticalAlignment: Text.AlignVCenter
                }

                onClicked: pageStack.push(Qt.resolvedUrl("../Ticketing/CheckinHistory.qml"))
            }

            ListHeading {
                id: departuresToFavsHeading
                ListItemText {
                    anchors.fill: parent.paddingItem
                    text: qsTrId("qtn_pt_homepage_nextDepartures") // "Next departures to..."
                    verticalAlignment: Text.AlignVCenter
                }
                visible: favorites.favoritesExisting
            }

            FavoritesList {
                id: favorites
                anchors { left: parent.left; right: parent.right }
                active: homePage.statusStr === "Activating" || homePage.statusStr === "Active"
            }
        }
    }
}
