import QtQuick 1.0



import "../../qtcomponents"
import "../../components"

import "../ApplicationModel.js" as App

// TODO Maybe change to notification dialog
PopupNotification {
    id: updateNotification

    property bool mandatory: Updater.appUpdate === "mandatory"

    title: qsTrId("qtn_pt_homepage_update_update") // "Update available"

    onHidden: {
        if (mandatory) {
            app.quit();
        } else {
            updateNotificationChecker.disabled = true;
            App.settings.lastUpdateNotificationTime = (new Date()).getTime();
            App.saveSettings();
        }
    }

    Column {
        id: updateUi
        property date updateStartTime
        property int updateStartOffset: 0

        anchors {
            left: parent.left
            right: parent.right
            leftMargin: 10;
            rightMargin: 10;
        }
        spacing: 10

        function cancel() {
            updateUi.state = "";
            updateNotification.hide();
            if (mandatory) {
                app.quit();
            } else {
                Updater.resetUpdate();
            }
        }

        Item {
            width: 10; height: 10
        }

        Label {
            id: text
            width: parent.width
            text: mandatory ?
                qsTrId("qtn_pt_homepage_update_mandatory_text") : // "A mandatory update of this application is available. Press "Update" to download and install or X to quit."
                qsTrId("qtn_pt_homepage_update_low_text") // "An update of this application is available. Press "Update" to download and install."
            wrapMode: Text.WordWrap
            font.pixelSize: 18
        }

        Row {
            id: buttons

            anchors.horizontalCenter: parent.horizontalCenter

            spacing: 10
            Button {
                text: qsTrId("qtn_pt_homepage_update_update") // "Update"
                onClicked: {
                    if (Updater.update()) {
                        updateUi.state = "downloading";
                        buttons.visible = false;
                        update.visible = true;
                        updateUi.updateStartOffset = 0;
                        updateUi.updateStartTime = new Date();
                        updateProgress.text = qsTrId("qtn_pt_homepage_update_downloading") // "Downloading..."
                    } else {
                        // show failure message
                    }
                }
            }            
            Button {
                text: mandatory ?
                    qsTrId("qtn_pt_homepage_update_exit") : //"Exit" :
                    qsTrId("qtn_pt_homepage_update_notnow") //"Not now"
                onClicked: {
                    updateUi.cancel();
                }
            }
        }

        Row {
            id: update
            visible: false

            spacing: 10

            Label {
                id: updateProgress
                anchors.verticalCenter: parent.verticalCenter

                font.pixelSize: 18
                width: 150
            }

            Button {
                id: cancel
                text: mandatory ?
                    qsTrId("qtn_pt_homepage_update_exit") : //"Exit" :
                    qsTrId("qtn_pt_homepage_update_cancel") // Cancel

                onClicked: {
                    Updater.cancelUpdate();
                    updateUi.cancel();
                }
            }

            Connections {
                target: Updater
                onUpdateProgress: {
                    if (updateUi.updateStartOffset) {
                        var downloaded = (bytesDownloaded - updateUi.updateStartOffset) /
                            (bytesTotal  - updateUi.updateStartOffset);
                        var elapsed = new Date() - updateUi.updateStartTime;

                        updateProgress.text = qsTrId("qtn_pt_homepage_update_timeleft").arg(
                            System.formatDuration(elapsed / downloaded, true));
                    } else {
                        updateUi.updateStartOffset = bytesDownloaded;
                        updateUi.updateStartTime = new Date();
                    }
                }
                onUpdateDownloadFinished: {
                    app.quit();
                }
            }
        }

        states: [
            State {
                name: "downloading"
                PropertyChanges {
                    target: text
                    text: qsTrId("qtn_pt_homepage_update_updating_text") // Please wait while the update is being downloaded. The application will close to apply the update.
                }
            }
        ]
    }

    Item {
        id: updateNotificationChecker

        property bool disabled: false

        Connections {
            target: updateNotificationChecker.disabled ? null : Updater

            onAppUpdateChanged: {
                checkForUpdate();
            }
        }

        Timer {
            id: updateCheckTimer
            interval: 2000

            onTriggered: {
                Updater.checkForUpdate(false);
            }
        }
    }

    function checkForUpdate() {
        if (Updater.appUpdate) {
            updateNotification.show(app);
        }
    }

    Component.onCompleted: {
        updateCheckTimer.start();
    }
}
