import QtQuick 1.0

import com.nokia.pt 1.0

import "../qtcomponents"
import "../components"

import "../components/styles/Styles.js" as Styles
import "ApplicationModel.js" as App

ListItem {
    id: locationItem
    property variant model
    property alias highlightText: titleText.highlightText

    signal favoriteButtonClicked

    Item {
        id: icon
        anchors.left: paddingItem.left
        anchors.verticalCenter: parent.verticalCenter
        width: Styles.listItemStyle.iconSpace
        height: parent.height

        SpinningImage {
            anchors.centerIn: parent
            asynchronous: true
            running: !!(model && model.source == "currentPosition" && App.currentPosition.isSearching)

            source: {
                if (model) {
                    if (model.source.indexOf("currentPosition") > -1) {
                        return "../../images/categories/position_%1.png".arg(App.currentPosition.state);
                    } else if (model.type == "PtStation") {
                        return "../../images/categories/station.png";
                    } else if (model.type == "PtPoi") {
                        switch (model.category) {
                        case Poi.EatDrink:
                            return "../../images/categories/eatdrink.png";
                        case Poi.GoingOut:
                            return "../../images/categories/goingout.png";
                        case Poi.SightsMuseums:
                            return "../../images/categories/sightsmuseums.png";
                        case Poi.Transport:
                            return "../../images/categories/transport.png";
                        case Poi.Accomodation:
                            return "../../images/categories/accomodation.png";
                        case Poi.Shopping:
                            return "../../images/categories/shopping.png";
                        case Poi.BusinessServices:
                            return "../../images/categories/businessservices.png";
                        case Poi.Facility:
                            return "../../images/categories/facility.png";
                        case Poi.LeisureOutdoor:
                            return "../../images/categories/leisureoutdoor.png";
                        case Poi.AdministrativeAreasBuildings:
                            return "../../images/categories/administrativeareasbuildings.png";
                        case Poi.NaturalGeographical:
                            return "../../images/categories/naturalgeographical.png";
                        }
                    }
                }

                return "../../images/categories/address.png";
            }
        }
    }

    Column {
        id: texts
        anchors.left: icon.right
        anchors.leftMargin: 5
//        anchors.leftMargin: paddingItem.anchors.leftMargin
        anchors.right: favoriteButtonIcon.left
        anchors.rightMargin: 10
        anchors.verticalCenter: parent.verticalCenter
        spacing: 5

        ListItemXLabel {
            id: titleText
            item: locationItem
            text: model &&
                    ((model.favorite && model.favoriteName)
                        || model.title || model.address.asTwoLinesFirst || model.displayName)
                  || ""
            width: parent.width
//            elide: Text.ElideMiddle
            role: "Title"
        }

        Row {
            anchors { left: parent.left; right: parent.right }
            spacing: 10

            Text {
                id: widthOfSubtitle
                visible: false
                smooth: false
                text: subTitleText.text
                font: subTitleText.font
            }

            ListItemText {
                id: subTitleText
                item: locationItem
                text: model ? model.description ||
                    (model.address.valid ?
                        ((model.favorite || model.title) ?
                            model.address.asOneLine :
                            model.address.asTwoLinesSecond) : "") : ""
                elide: Text.ElideRight
                width: Math.min(parent.width - distanceText.width - parent.spacing, widthOfSubtitle.paintedWidth)
                role: "SubTitle"
            }

            ListItemText {
                id: distanceText
                item: locationItem
                text: {
                    if (model && !model.value && App.currentPosition && !App.currentPosition.notAvailable) {
                        var dist = App.computeDistance(App.currentPosition.location, model);
                        return dist > 0 ? System.formatDistance(dist) : "";
                    }

                    return "";
                }
                visible: text.length
                role: "SubTitle"
            }
        }
    }

    Sprite {
        id: favoriteButtonIcon
        anchors {
            verticalCenter: parent.verticalCenter
            right: parent.right
            rightMargin: 8
        }
        height: 36
        width: 36
        source: "../../images/favorite_place.png"
        indexY: model && model.favorite ? 1 : 0
        visible: model !== App.currentPosition.location;
    }

    MouseArea {
        id: favoriteButtonArea

        enabled: model !== App.currentPosition.location;
        anchors { top: parent.top; bottom: parent.bottom; right: parent.right; }
        width: height
        z: 10

        Component.onCompleted: clicked.connect(locationItem.favoriteButtonClicked)
    }
}
