import QtQuick 1.0
import "../ApplicationModel.js" as App

import com.nokia.pt 1.0
import MapsPlugin 1.0

Rectangle {
    id: root
    anchors.fill: parent

    property alias stations: icons.model
    property variant departures        // available departures for stations
    property variant stationIndex
    property variant location           // search center

    property int coveredArea: calculateArea(location, stations)

    function calculateArea(loc, stations) {
        if (!loc || !stations) return 0;
        var dist = 0;
        stations.forEach(function(station) {
            dist = Math.max(dist, App.computeDistance(location, station));
        });
        return dist;
    }

    MapQmlItem {
        id: currentPositionMarker
        center.latitude: App.currentPosition.location.latitude
        center.longitude: App.currentPosition.location.longitude
        Image {
            visible: !App.currentPosition.notAvailable
            source: "../../../images/categories/position_badge.png"
        }
        Component.onCompleted: {
            map.addQmlItem(currentPositionMarker);
        }
    }

    MapQmlItem {
        id: coveredAreaIndicator
        center.latitude: location && location.latitude || 0
        center.longitude: location && location.longitude || 0
        Item {
            width: coveredArea * 350 / map.zoomScale
            height: coveredArea * 350 / map.zoomScale
            Rectangle {
                width: parent.width
                height: parent.height
                opacity: .5
                radius: width / 2
                border.color: "#404040"
                border.width: 1
                visible: height < 500 && width < 500
            }
            Rectangle {
                x: 6
                y: 6
                width: parent.width - 12
                height: parent.height - 12
                opacity: .1
                radius: width / 2
                border.color: "#404040"
                border.width: 10
                visible: height < 500 && width < 500
            }
        }
        Component.onCompleted: {
            map.addQmlItem(coveredAreaIndicator);
        }
    }

    function isEnabled(departures) {
        return !!(departures && departures.length);
    }

    Repeater {
        id: icons
        Item {
            id: mapItem

            StationMarker {
                id: marker
                disabled: !isEnabled(root.departures[index])
                center.latitude: modelData.latitude
                center.longitude: modelData.longitude
                onSelected: stationIndex = index;
            }

            Component.onCompleted: map.addQmlItem(marker);
            Component.onDestruction: map.removeQmlItem(marker);
        }
    }

    // Get GOOM events
    Connections {
        target: PtApplication
        onLowMemoryEvent: map.freeGraphicResource()
        onGoodMemoryEvent: map.useGraphicResource()
    }

    Map {
        id: map
        anchors.fill: parent

        center.latitude: location && location.latitude || 0
        center.longitude: location && location.longitude || 0

        zoomScale: coveredArea || 100

        automaticRotating: false
    }
}
