import QtQuick 1.0
import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import "styles"
import "../ApplicationModel.js" as App

ListItem {
    id: item
    height: Math.max(style.minHeight, __calcHeight + 14)
    width: parent ? parent.width : undefined

    property bool smooth: false//!(!pageStack || pageStack.busy) && !list.flicking

    property real relTime

    property int __calcHeight: lineSymbol.height + (platformText.visible ? platformText.paintedHeight : 0)

    style: DepartureItemStyle {}

    // Transport type icon
    Image {
        id: icon
        anchors {
            top: parent.top
            left: parent.left
            topMargin: Math.min(14, (item.height - icon.height) / 2)
            leftMargin: 10
        }
        width: 34
        opacity: 0.8
        source: modelData.line.transitType.defaultType.iconUri(34)
        smooth: item.smooth
        fillMode: Image.PreserveAspectFit
        asynchronous: true
    }

    LineItem {
        id: lineSymbol
        anchors {
            top: item.top
            topMargin: Math.max(7, (60 - __calcHeight) / 2)
            left: icon.right
            leftMargin: 12
            right: time.left
            rightMargin: 8
        }
        threshold: 1
        line: modelData.line
        symbolTopPadding: isShortLayout && platformText.visible && (destinationElement.lineCount === 1) ? platformText.paintedHeight / 2 : 0
        smooth: true
    }

    // departure time
    Text {
        id: time
        anchors {
            top: lineSymbol.top
            topMargin: 3
            right: parent.right
            rightMargin: 8
        }
        horizontalAlignment: Text.AlignRight
        smooth: item.smooth
        property variant __departureTime: System.formatDateTime(modelData.time, "time");
        text: __departureTime.datetime + '<font size="10px">%1</font>'.arg(__departureTime.ampm || "")
        color: item.style.color
        font: item.style.font
    }

    // platform & late infos
    Text {
        id: platformText
        anchors {
            top: lineSymbol.bottom
            left: lineSymbol.left
            leftMargin: lineSymbol.textIndent
        }
        visible: !!text
        text: modelData.platform ? qsTrId("qtn_pt_journeydetails_platform").arg(modelData.platform) : ""
        color: item.style.color
        font: item.style.font
    }

    states: State {
        name: "relative"
        PropertyChanges {
            target: time
            text: (relTime == 0 ? qsTrId("qtn_pt_timepicker_now")  // "Now"
                               :  (relTime > 36000 ? System.formatTime(modelData.time, "time")
                                                   : qsTrId("qtn_pt_departureitem_minutes")
                                                         .arg(relTime)))
                      .replace(/\s*(PM|AM|min)/, '<font size="10px">$1</font>') // "%1 min"
        }
    }
}
