import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

ListItem {
    id: item

    property string title: ""
    property string iconSource: ""
    property string nextDepartures: ""

    Item {
        id: icon
        x: 5
        width: 60
        height: parent.height

        Image {
            anchors.centerIn: parent
            asynchronous: true
            opacity: iconSource ? (item.enabled ? 1 : 0.2) : 0
            source: iconSource
            fillMode: Image.PreserveAspectFit
            height: Math.min(parent.height, sourceSize.height)
            width: Math.min(parent.width, sourceSize.width)
            Behavior on opacity { NumberAnimation { duration: 500 } }
        }
    }

    Column {
        anchors {
            verticalCenter: parent.verticalCenter
            left: icon.right
            leftMargin: 5
            right: item.paddingItem.right
        }
        spacing: 5
        ListItemText {
            style: item.style
            role: "Title"
            item: item
            text: displayName
            width: parent.width
            opacity: item.enabled ? 1 : 0.4
            elide: Text.ElideMiddle
            Behavior on opacity { NumberAnimation { duration: 250 } }
        }
        Item {
            width: parent.width
            height: Math.max(loadingText.height, departuesText.height)
            ListItemText {
                id: loadingText
                style: item.style
                item: item
                role: "SubTitle"
                text: qsTrId("qtn_pt_departureitem_loading")
                opacity: nextDepartures ? 0 : 1
                y: nextDepartures ? 20 : 0
                width: parent.width
                Behavior on opacity { NumberAnimation { duration: 250 } }
                Behavior on y { NumberAnimation { duration: 250; easing.type: "InQuad" } }
            }
            ListItemText {
                id: departuesText
                style: item.style
                item: item
                role: "SubTitle"
                text: nextDepartures || ""
                elide: Text.ElideRight
                opacity: nextDepartures ? (item.enabled ? 1 : 0.4) : 0
                y: nextDepartures ? 0 : -5
                width: parent.width
                Behavior on opacity { NumberAnimation { duration: 250 } }
                Behavior on y { NumberAnimation { duration: 250; easing.type: "InQuad" } }
            }
        }
    }
}
