import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Page {
    objectName: "nearbyStationPage"

    title: qsTrId("qtn_pt_departures_station_title") // "Departures"

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("StationDetails");
        }
    }

    property variant departures
    property variant station
    property variant transportTypeFilter

    property int     lateTime: 100         // how much seconds lines should shown from the past

    // timer removing old departures
    Timer {
        interval: 30000
        running: !!departures && parent.visible
        repeat: true
        onTriggered: { // removes the old departures and keeps the position of the current visible elements
            var index = list.indexAt(list.contentX, list.contentY + 5),
                len = departures.length,
                cutTime = System.currentTime - lateTime * 1000;

            departures = departures.filter(function(elem) {
                    return elem.time >= cutTime;
                });
            if (len !== departures.length) {
                list.positionViewAtIndex(departures.length - len + index, ListView.Beginning);
            }
        }
    }

    QtObject {
        id: internal
        property variant metaInfo: getMetaInfo(departures)
        function getMetaInfo(model) {
            if (!model) return [];
            var tmp = {},
            info = [];
            model.forEach(function(item) {
                              var code = item.line.transitType.code;
                              if (!tmp[code]) {
                                  tmp[code] = true;
                                  info.push({
                                          code: code,
                                          iconUri: item.line.transitType.defaultType.iconUri(34),
                                      });
                              }
                          });
            return info;
        }
    }

    ViewHeading {
        id: headerBar
        contentHeight: texts.height

        ViewHeadingText {
            id: texts
            anchors {
                left: parent.paddingItem.left
                right: parent.paddingItem.right;
                verticalCenter: parent.paddingItem.verticalCenter
            }
            opacity: departures && !departures.length ? 0.5 : 1
            text: station ? station.displayName : ""
            width: parent.width
        }
    }

    function getFilteredModel(model, filter) {
        // is filter empty ?
        for (var key in filter) { // no loop, just filter in case of its not empty
            return model.filter(function(elem) {
                return filter[elem.line.transitType.code];
            });
        }
        return model;
    }

    ListView {
        id: list

        model: departures && getFilteredModel(departures, transportTypeFilter)
        opacity: model ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 250 } }

        anchors.top: headerBar.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        clip: true
        state: ""
//        cacheBuffer: 500

        delegate: NearbyDepartureItem {
            id: wrapper
            width: list.width
            state: list.state
            relTime: Math.ceil((modelData.time - System.currentTime)/60000);

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    list.state = list.state == "relative" ? "" : "relative";
                }
            }
        }
    }

    ScrollIndicator {
        scrollArea: list
        anchors.top: headerBar.bottom
        anchors.bottom: parent.bottom
        anchors.right: parent.right
    }

    Item {
        anchors.fill: list
        z: 300
        LoadingIndicator {
            opacity: !departures ? 1 : 0
            Behavior on opacity { NumberAnimation { duration: 250 } }
            visible: opacity > 0
        }
        Text {
            text: qsTrId("qtn_pt_departurenearbystations_nodepartures")
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.margins: 20
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.Wrap
            visible: !!(departures && !departures.length)
        }
    }

    tools: ToolBarLayout {
        BackToolButton {
            objectName: "backBtn"
        }

        ToolIcon {
            objectName: "settingsBtn"
            id: optionsButton
            iconSource: "../../../images/toolbar/" + (isFiltering(transportTypeFilter) ? "settings-active.png" : "settings.png")
            enabled: internal.metaInfo.length > 1

            onClicked: {
                transportTypeFilter = transportTypeFilter || createDefaultFilter(internal.metaInfo);
                var page = App.pushPage(pageStack, Qt.resolvedUrl("../TransportTypeFilterPage.qml"), { // create that dialog every time, otherwise sideeffects in that dialog
                    filter: transportTypeFilter,
                    metaInfo: internal.metaInfo
                }, function() {
                    if (page.result) transportTypeFilter = page.filter;
                });
            }

            function createDefaultFilter(metaInfo) {
                var filter = {};
                metaInfo.forEach(function(item) { filter[item.code] = true; });
                return filter;
            }

            function isFiltering(filter) {
                filter = filter || {}
                for (var id in filter) if (!filter[id]) return true;
                return false;
            }
        }
    }
}
