import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Rectangle {
    id: calendar
    color: "#dfdfdf"

    signal clicked(int selectedIndex)

    property string pageStatusStr: ""

    property int selectedItemIndex: -1

    property real timeScale: 600000
    property int timeSliceWidth: 75
    property int currTimeOffset: (currentTime - graphStartTime) / timeScale * timeSliceWidth
    property int timeSlicesCount: 0

    property int graphWidth: Math.floor(timeSlicesCount * timeSliceWidth)

    property int count: listView.count

    property real currentTime: Date.now()
    property real graphStartTime: Date.now()

    property bool showAbsoluteTimes: true

    property bool needsTimeScaleUpdate: false

    signal loadEarlier(variant snapper)
    signal loadLater(variant snapper)

    onPageStatusStrChanged: {
        if ("Active" === statusStr) {
            selectedItemIndex = -1;
        } else if ("Deactivating" === statusStr) {
            leftSnapper.finished();
            rightSnapper.finished();
        }
    }

    function getCurrentPosition() {
        return {
                time: graphStartTime + flickie.contentX / timeSliceWidth*timeScale,
                conn: (flickie.contentY - 30) / 110 // JourneyalendarItemHeight
        };
    }

    function setCurrentPosition(time, conn) {
        flickie.contentY = 30 + conn * 110 // JourneyalendarItemHeight
        flickie.contentX = (time - graphStartTime) / timeScale * timeSliceWidth
    }

    function setCurrentIndex(index) {
        if (index < 0 || index >= listView.model.length) {
            return;
        }

        selectedItemIndex = index;

        var item = listView.model[index];

        flickie.contentY = Math.max(0,
                                    Math.min(30 + index * 110 - flickie.height / 2,
                                             flickie.contentHeight - flickie.height)) // JourneyalendarItemHeight
        flickie.contentX = Math.max(0,
                                    Math.min((item.startTime - graphStartTime) / timeScale * timeSliceWidth - 30,
                                             flickie.contentWidth - flickie.width))
    }

    function timeScaleFromJourneyDuration( duration ) {
        var NATURAL_SCALE = 0.35;
        var durationInMinutes = duration / 60 / 1000;
        var niceScalesInMinutes = [1, 2, 5, 10, 15, 20, 30, 60, 90, 120, 180, 240, 300, 360, 480, 720, 1440]
        var timeScale =niceScalesInMinutes[niceScalesInMinutes.length-1] * 60 * 1000;

        for(var i=0; i< niceScalesInMinutes.length -1; i++) {
            if( 0.6 * niceScalesInMinutes[i] + 0.4 * niceScalesInMinutes[i+1] > durationInMinutes * NATURAL_SCALE) {
                timeScale = niceScalesInMinutes[i] * 60 * 1000;
                break;
            }
        }
        return timeScale;
    }

    function setModel(model) {
        if (model && model.length) {
            showAbsoluteTimes = model[0].timetableBased;

            var startTime = model[0].startTime;
            var endTime =  model[0].endTime;
            var longestJourney = 0;
            for (var i = 0, l = model.length; i < l; i++) {
                if (model[i].timetableBased) {
                    endTime = Math.max(endTime, model[i].endTime);
                    longestJourney = Math.max(longestJourney, model[i].endTime - model[i].startTime);
                } else {
                    endTime = Math.max(endTime, model[i].startTime + model[i].estimatedDuration);
                    longestJourney = Math.max(longestJourney, model[i].estimatedDuration);
                }
            }

            var screenFactor = 1 / calendar.width * 360; // all the calc needs to be refactored. --> strange values

            timeScale = timeScaleFromJourneyDuration( longestJourney * screenFactor);

            var totalDuration = endTime - startTime;
            graphStartTime = showAbsoluteTimes ? startTime - startTime % timeScale : 0;
            currentTime = Date.now();

            timeSlicesCount = Math.max(Math.ceil(calendar.width/timeSliceWidth), Math.ceil(totalDuration / timeScale) + 2);

            listView.model = model;

            flickie.contentY = 0;
            flickie.contentX = Math.min((startTime - graphStartTime) / timeScale * timeSliceWidth,
                                        flickie.contentWidth - calendar.width);
        } else {
            listView.model = model;

            timeSlicesCount = 0;
            flickie.contentY = 0;
            flickie.contentX = 0;
        }

        selectedItemIndex = -1;
        rightSnapper.finished();
        leftSnapper.finished();
    }

    function updateTimeScale() {
        var model = listView.model;
        setModel([]);
        setModel(model);
        needsTimeScaleUpdate = false;
    }

    Connections {
        target: app
        onInPortraitChanged: {
            if (routePlanner.statusStr === "Active") {
                updateTimeScale();
            } else {
                needsTimeScaleUpdate = true;
            }
        }
    }

    Timer {
        interval: 5000
        running: calendar.visible && System.appInForeground
        repeat: true
        triggeredOnStart: true
        onTriggered: {
            currentTime = Date.now();
        }
    }

    property int timePos: Math.floor(currTimeOffset - 2 + timeSliceWidth*0.5)
    property int leftListOffset: 0
    property int rightListOffset: 0

    // The background
    Item {
        anchors.fill: flickie

        Rectangle {
            id: contentBackground
            z: 0
            color: "#f0f0f0"
            height: Math.max(parent.height, flickie.contentHeight); width: Math.max(parent.width, flickie.contentWidth - rightListOffset)
            x: -flickie.contentX + leftListOffset;
        }
    }

    LeftSnapper {
        id: leftSnapper

        visible: showAbsoluteTimes
        enabled: showAbsoluteTimes
        timeLineHeight: tiliBackground.height

        onStarted: {
            leftListOffset = 100;
            flickie.contentX += 100;
            calendar.loadEarlier(leftSnapper);
        }

        onStopped: {
            leftListOffset = 0;
        }

        Component.onCompleted: {
            parent = tili.contentItem
        }
    }

    RightSnapper {
        id: rightSnapper

        visible: showAbsoluteTimes
        enabled: showAbsoluteTimes
        timeLineHeight: tiliBackground.height

        onStarted: {
            rightListOffset = 100;
            calendar.loadLater(rightSnapper);
        }

        onStopped: {
            rightListOffset = 0;
        }

        Component.onCompleted: {
            parent = tili.contentItem
        }
    }

    // The buttons under each calendar item
/*
    ListView {
        id: buttons

        interactive: false
        orientation: ListView.Vertical
        anchors.fill: flickie
        contentX: flickie.contentX - leftListOffset
        contentY: flickie.contentY

        model: listView.model

        delegate: Image {
            state: "up"
            height: 110
            width: Math.max(parent.width, flickie.contentWidth - rightListOffset)
            source: "../../../images/calendar_button_" + state + ".png"
        }
    }
*/
    // The time lines on the canvas
    ListView {
        anchors.fill: flickie
        interactive: false
        orientation: ListView.Horizontal
        contentX: flickie.contentX - leftListOffset
        contentWidth: listView.contentWidth

        model: timeSlicesCount

        header: Item { width: Math.floor(timeSliceWidth*0.5); height: 15 }

        delegate: Item {
            width: timeSliceWidth
            anchors.top: parent.top; anchors.bottom: parent.bottom;

            z: 100

            Rectangle {
                width: 1
                anchors.top: parent.top; anchors.bottom: parent.bottom;
                color: "#cbcbcb"
            }
        }
    }

    // The actual items
    ListView {
        id: listView
        anchors.fill: parent // will be flickie in the end, see Component.onCompleted
        clip: true
        z: 0

        property Item lastSelectedItem

        interactive: false
        contentX: flickie.contentX - leftListOffset
        contentY: flickie.contentY

        Component.onCompleted: {
            listView.parent = flickie; // else clicking the elements doesn't work
        }

        delegate: JourneyCalendarItem {
            id: calitem
            model: modelData

            z: 200
            selected: index === selectedItemIndex

            timeScale: calendar.timeScale
            timeSliceWidth: calendar.timeSliceWidth

            contentX: flickie.contentX - leftListOffset
            contentWidth: flickie.contentWidth
            currentTimeOffset: Math.max(timePos, 0)
            currentTime: calendar.currentTime

            xOffset: Math.floor((
                (model.timetableBased ? model.startTime : 0) - graphStartTime)/timeScale * timeSliceWidth + timeSliceWidth*0.5)

            onClicked: {
                selectedItemIndex = index;
                calendar.clicked(index);
            }
        }
    }

    // Only one flickable for the multiple lists
    Flickable {
        id: flickie
        anchors.top: tiliBackground.bottom
        anchors.bottom: parent.bottom
        anchors.right: parent.right
        anchors.left: parent.left

        flickableDirection: Flickable.HorizontalAndVerticalFlick

        contentHeight: listView.contentHeight
        contentWidth: graphWidth + rightListOffset
    }

    // The time line header background
    Item {
        id: tiliBackground
        property color gradientStart: "#858585"
        property color gradientEnd: "#6D6D6D"
        states: [
            State {
            name: "pressed"
            when: timelinemouse.pressed && !routePlanner.isSimpleRouting

            PropertyChanges {
                target: tiliBackground
                gradientStart: "#1080dd"
                gradientEnd: "#3292e2"
            }
        }
        ]

        transitions: [
            Transition {
                from: "pressed"; to: ""
                ColorAnimation { target: tiliBackground; property: "gradientStart"; duration: 200; easing.type: Easing.InQuad }
                ColorAnimation { target: tiliBackground; property: "gradientEnd"; duration: 200; easing.type: Easing.InQuad }
            }
        ]

        Rectangle {
            id: topHairLine
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            color: "#919191"
            height: 0
        }

        Rectangle {
            id: gradient
            anchors {
                top: topHairLine.bottom
                left: parent.left
                right: parent.right
                bottom: bottomHairLine2.top
            }
            gradient: Gradient {
                GradientStop {
                    position: 0.0
                    color: tiliBackground.gradientStart
                }
                GradientStop {
                    position: 1.0
                    color: tiliBackground.gradientEnd
                }
            }
        }

        Rectangle {
            id: bottomHairLine2
            anchors {
                bottom: bottomHairLine.top
                left: parent.left
                right: parent.right
            }
            color: "#3B3B3B"
            height: 1
        }

        Rectangle {
            id: bottomHairLine
            anchors {
                bottom: parent.bottom
                left: parent.left
                right: parent.right
            }
            color: "#B6B6B6"
            height: 1
        }

        anchors {
            top: parent.top
            right: parent.right
            left: parent.left
        }
        height: 40
        z: 1

        MouseArea {
            id: timelinemouse
            anchors.fill: parent
            onClicked: {
                if (routePlanner.isSimpleRouting) return;
                var page = pageStack.push(timePickerPage);
                if (!routePlanner.filter) page.reset();
            }
        }

        // The time line below the header
        ListView {
            id: tili
            anchors.fill: tiliBackground

            interactive: false
            orientation: ListView.Horizontal
            contentX: flickie.contentX - leftListOffset

            model: timeSlicesCount

            delegate: Item {
                height: tili.height
                width: timeSliceWidth

                DateTime {
                    property real time: graphStartTime + timeScale * index

                    anchors.centerIn: parent

                    datetime: time
                    format: showAbsoluteTimes ? "time" : "duration"

                    color: "white"
                    font {
                        pixelSize: 18
                        bold: false
                        letterSpacing: -1
                    }
                }
            }
        }
    }

    Image {
        id: stripes
        anchors {
            left: parent.left
            top: parent.top
            bottom: parent.bottom
        }
        width: timePos - flickie.contentX + leftListOffset - 4
        source: "../../../images/stripes.png"
        fillMode: Image.Tile
        opacity: .3
        visible: !routePlanner.isSimpleRouting
    }

    Image {
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: stripes.right
        }
        source: "../../../images/current_time_with_shadow.png"
        height: parent.height
        width: 8
        fillMode: Image.TileVertically
        z: 2
        sourceSize.width: width
        sourceSize.height: 32
    }
}
