import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"

import "../ApplicationModel.js" as App
import "JourneyDetails.js" as Logic

Item {
    id: journeyDetails
    property variant connection
    property variant parentPageState
    property int totalPages
    property int currentPage

    property QtObject style: JourneyDetailsStyle {}

    onConnectionChanged: {
        if (connection && parentPageState !== 0) {
            list.model = connection.steps;
        }
    }

    Flickable {
        anchors {
            fill: parent
            bottomMargin: 50
        }

        contentHeight: content.height

        Column {
            id: content

            anchors {
                left: parent.left
                right: parent.right
            }

            // header bar
            ViewHeading {
                id: bar

                contentHeight: Math.max(timeLeft.height, stepsAndTime.height)
                anchors {
                    left: parent.left
                    right: parent.right
                }

                ViewHeadingText {
                    id: timeLeft
                    anchors {
                        left: parent.paddingItem.left
                        verticalCenter: parent.paddingItem.verticalCenter
                        right: stepsAndTime.left
                        rightMargin: 6
                    }

                    text: connection
                          && connection.timetableBased
                          && Logic.buildTimeToStartText(connection ? connection.startTime : 0, currentTime)
                          || ""
                }


                Row {
                    id: stepsAndTime
                    anchors {
                        verticalCenter: parent.paddingItem.verticalCenter
                        right: parent.paddingItem.right
                    }
                    spacing: 6

                    Row {
                        id: transfereCounts
                        visible: (connection && connection.transfers > 0)
                        Image {
                            anchors.verticalCenter: parent.verticalCenter
                            source: "../../../images/journeyplanner/transfer_count.png"
                            asynchronous: true
                        }
                        Item {
                            width:6
                            height:1
                        }

                        ViewHeadingText {
                            text: connection ? connection.transfers : ""
                        }
                        Item {
                            width:6
                            height:1
                        }
                    }

                    Image {
                        anchors.verticalCenter: parent.verticalCenter
                        source: "../../../images/journeyplanner/total_duration.png"
                        asynchronous: true
                    }

                    ViewHeadingText {
                        text: connection
                              ? (connection.timetableBased ?
                                     System.formatDuration(connection.duration) :
                                 qsTrId("qtn_pt_estimate_time").arg(System.formatDuration(connection.estimatedDuration, true)))
                              : ""
                    }
                }
            }

            PageIndicator {
                anchors {
                    left: parent.left
                    right: parent.right
                }
                totalPages: journeyDetails.totalPages
                currentPage: journeyDetails.currentPage
            }

            Repeater {
                id: list

                delegate: JourneyDetailsDelegate {
                    style: journeyDetails.style
                    width: parent.width
                }
            }

            Item {  // spacer
                width: 2
                height: 3
            }

            Item {
                id: footer
                height: Math.max(isBikeAllowedImage.height, noWarrantyText.height)
                anchors {
                    left: parent.left
                    right: parent.right
                }

                Image {
                    id: isBikeAllowedImage
                    visible: Logic.bikeAllowed(list.model)

                    anchors{top: parent.top; topMargin: 6; left:parent.left; leftMargin:8}
                    source: "../../../images/bicycle_small.png"
                    asynchronous: true
                }
                Label {
                    id: noWarrantyText
                    text: qsTrId("qtn_pt_journey_no_warranty")

                    anchors { left: isBikeAllowedImage.right; right: parent.right; rightMargin: 10; top:parent.top; topMargin:12 }
                    wrapMode: "WordWrap"
                    color: "#888"
                    font.pixelSize: 12
                    horizontalAlignment: Text.AlignRight
                }
            }
        }
    }

    Rectangle { // black right border
        color: "black"
        anchors {
            top: parent.top
            bottom: parent.bottom
            right: parent.right
        }
        width: 1
    }
}
