import QtQuick 1.0
import com.nokia.pt 1.0

import "../../components"
import "../ApplicationModel.js" as App

// variable "list" came from the JourneyDetails view
Column {
    id: item

    // Middle alignment point
    property int middlePosition: 97

    // Some pre-calculations on where transfers occur, or where the user is walking
    property bool isFirst: index === 0
    property bool isLast: (index == list.count-1)

    property bool isWalk: modelData.line.isWalk

    property bool prevIsWalk: isFirst || list.model[index - 1].line.isWalk
    property bool nextIsWalk: isLast || list.model[index + 1].line.isWalk

    property int realIndex: (isFirst && isWalk) ? 1 : 0

    property string fromTitle: isFirst ?
                        (from ? from.displayName || from.address.asOneLine : "") :
                        modelData.from.displayName || modelData.from.address.asOneLine
    property string toTitle: isLast ?
                        (to ? to.displayName || to.address.asOneLine : "") : ""

    property QtObject style: JourneyDetailsStyle {}
    z: list.count - index

    function getBackgroundSource(idx, pressed) {
        var kind = (idx % 2) ? "-transfer" : "";
        pressed = (pressed) ? "-pressed" : "";
        return "../../../images/list-item-background" + kind + pressed + ".png"
    }

    function getWalkString(modelData) { // "About x m / y min"
        return qsTrId("qtn_pt_journeydetails_walkdistancetime").arg(
            System.formatDistance(
                modelData.length >= 0
                    ? modelData.length
                    : App.computeDistance(modelData.from, modelData.to))).arg(
            System.formatDuration(
                modelData.endTime - modelData.startTime));
    }

    function openStopDetails(isDestination) {
        pageStack.push(Qt.resolvedUrl("StationDetailsPage.qml"), {
            station: (isDestination) ? modelData.to : modelData.from,
            line: modelData.line
        });
    }

    function openLineDetails() {
        pageStack.push(Qt.resolvedUrl("LineDetailsPage.qml"), {
            step: modelData
        });
    }

    function openWalkNavigation() {
        if (!walkDialog.isShown /*&& !startNavTimer.running*/) {
            walkDialog.navigate = {
                    name: index == list.count -1 ? to.displayName : modelData.to.displayName,
                    latitude: modelData.to.latitude,
                    longitude: modelData.to.longitude
            }
            walkDialog.start();
        }
    }

    // start point
    Image {
        id: lineStart

        source: getBackgroundSource(realIndex, mouseAreaStart.pressed)

        z: 1
        width: parent.width
        height: item.style.height

        fillMode: Image.TileHorizontally

        Image {
            id: walkStart
            visible: isFirst && isWalk
            source: "../../../images/icon-walking.png"

            anchors.right: titleStart.left
            anchors.rightMargin: 5

            anchors.verticalCenter: parent.verticalCenter
        }

        Image {
            id: walkMapIcon1
            visible: isWalk && isFirst
            source: "../../../images/show_on_map_34px.png"

            anchors.right: parent.right
            anchors.rightMargin: 9

            anchors.verticalCenter: parent.verticalCenter
        }


        // The step title
        Text {
            id: titleStart

            text: walkStart.visible ? getWalkString(modelData) : fromTitle

            anchors.left: parent.left
            anchors.leftMargin: middlePosition + (walkStart.visible ? 24 : 0)

            anchors.right: parent.right
            anchors.rightMargin: isWalk ? 45 : 10

            anchors.top: parent.top
            anchors.topMargin: 23
            anchors.bottom: parent.bottom
            anchors.bottomMargin: walkStart.visible ? 0 : 23

            color: walkStart.visible ? item.style.walkColor : item.style.color
            clip: true
            font: walkStart.visible ? item.style.walkFont : item.style.font
            elide: walkStart.visible ? Text.ElideNone : Text.ElideRight
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        }

        // the step title if walking
        Label {
            id: subTitleStart
            visible: walkStart.visible
            text: qsTrId("qtn_pt_journeydetails_from_location").arg(fromTitle)

            anchors.left: titleStart.left
            anchors.right: titleStart.right

            anchors.top: parent.top
            anchors.topMargin: 2

            color: item.style.hintColor
            font: item.style.hintFont

            elide: Text.ElideRight
        }

        // trip start
        DateTime {
            format: "time"
            visible: modelData.timetableBased && (!isWalk || isFirst)
            datetime: modelData.startTime

            anchors.bottom: prevIsWalk ? undefined : parent.bottom
            anchors.bottomMargin: 2

            anchors.verticalCenter: prevIsWalk ? parent.verticalCenter : undefined
            anchors.verticalCenterOffset: -2

            anchors.horizontalCenter: parent.left
            anchors.horizontalCenterOffset: 34

            color: item.style.timeColor
            font: item.style.timeFont

            horizontalAlignment: "AlignRight"
        }

        // trip end
        DateTime {
            format: "time"
            visible: modelData.timetableBased && (!isWalk || isLast)
            datetime: modelData.endTime

            anchors.top: nextIsWalk ? undefined : parent.top
            anchors.topMargin: item.height + 2

            anchors.verticalCenter: nextIsWalk ? line.bottom : undefined

            anchors.horizontalCenter: parent.left
            anchors.horizontalCenterOffset: 34

            color: item.style.timeColor
            font: item.style.timeFont

            horizontalAlignment: "AlignRight"
        }

        // change from platform or
        // riding time if simple routing
        Text {
            visible: !isWalk && modelData.fromPlatform
            text: qsTrId("qtn_pt_journeydetails_platform").arg(modelData.fromPlatform)

            anchors.left: parent.left
            anchors.leftMargin: middlePosition

            anchors.bottom: parent.bottom
            anchors.bottomMargin: 3

            color: item.style.hintColor
            font: item.style.hintFont
        }

        // change to platform
        Text {
            visible: !isWalk && modelData.toPlatform
            text: qsTrId("qtn_pt_journeydetails_platform").arg(modelData.toPlatform)

            anchors.left: parent.left
            anchors.leftMargin: middlePosition

            anchors.top: parent.top
            anchors.topMargin: 3 + (isLast ? lineStart.height + lineDest.height : item.height)

            color: item.style.hintColor
            font: item.style.hintFont
        }

        JourneyLine {
            id: line

            anchors {
                left: parent.left
                leftMargin: 69
                top: parent.top
                topMargin: Math.floor(item.style.height / 2)
            }
            smooth: true

            width: 20
            height: item.height - anchors.topMargin + ((item.isLast) ? -Math.floor(item.style.height / 2) : Math.floor(item.style.height / 2))

            ticks: (isWalk) ? 0 : (modelData.stops.length > 12) ? 10 : (modelData.stops.length - 2)
            color: modelData.line.lineScheme.color || "#000"
            isFirst: item.isFirst
            isLast: item.isLast
        }

        MouseArea {
            id: mouseAreaStart

            anchors.fill: parent

            onClicked: {
                if (isFirst && isWalk) {
                    openWalkNavigation()
                } else {
                    openStopDetails()
                }
            }
        }
    }

    // destination to - is not visible if walk (first or last)
    Image {
        id: lineDest

        visible: !((isFirst || isLast) && isWalk)
        source: getBackgroundSource(realIndex + 1, mouseAreaDest.pressed)

        height: isWalk ? item.style.height : Math.max(item.style.height - 5, (srTimeLabel.visible ? srTimeLabel.height : 0) + lineSymbol.height + 16)
        width: parent.width

        fillMode: Image.TileHorizontally

        Image {
            id: transportType
            anchors {
                left: parent.left
                leftMargin: 19
                verticalCenter: parent.verticalCenter
                verticalCenterOffset: -1
            }

            source: (!modelData.line.isWalk && modelData.line.lineScheme.iconUri(34)) || ""

            fillMode: Image.PreserveAspectFit

            width: 34
            height: 34
            smooth: true
        }

        // riding time if simple routing
        Label {
            id: srTimeLabel
            anchors {
                top: parent.top
                topMargin: 1
                left: parent.left
                leftMargin: middlePosition
            }
            visible: !isWalk && !modelData.timetableBased
            text: qsTrId("qtn_pt_journeydetails_estimateridingtime").arg(
                      System.formatDuration(modelData.endTime - modelData.startTime));

            color: item.style.hintColor
            font: item.style.hintColor
        }

        // LineSymbol + dest
        LineItem {
            id: lineSymbol
            anchors {
                top: srTimeLabel.visible ? srTimeLabel.bottom : parent.top
                topMargin: (parent.height - height) / 2 - (srTimeLabel.visible ? srTimeLabel.height - 5 : 0)
                left: parent.left
                leftMargin: middlePosition
                right: lateIconContainer.visible ? lateIconContainer.left : parent.right
                rightMargin: 8
            }
            threshold: 1
            style: item.style
            visible: !isWalk
            line: modelData.line
            smooth: true
        }

        // late information
        Column {
            id: lateIconContainer

            visible: !!modelData.hasDelayInfo

            anchors {
                right: parent.right
                rightMargin: 5
                verticalCenter: parent.verticalCenter
            }

            spacing: -2

            Image {
                id: lateIcon

                source: modelData.departureDiff <= 0 ? "../../../images/indicator-on-time.png" :
                        "../../../images/indicator-delay.png"
                anchors.horizontalCenter: parent.horizontalCenter
            }

            // Late train label
            Label {
                id: lateLabel

                visible: modelData.departureDiff > 0
                text: "+" + modelData.departureDiff / 60000

                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -2

                font.pixelSize: 16
                color: "#ba360e"
            }

        }

        // destination of the line or walk distance (walkItem in the middle)
        Label {
            id: titleDest

            anchors.left: lineSymbol.visible ? lineSymbol.right : walkDest.right
            anchors.leftMargin: 10

            anchors.right: parent.right
            anchors.rightMargin: 5 + (lateIconContainer.visible ? lateIconContainer.width + lateIconContainer.anchors.leftMargin : 0)

            anchors.verticalCenter: parent.verticalCenter

            text: isWalk ?
                      getWalkString(modelData) :
                      modelData.line.direction && qsTrId("qtn_pt_journeydetails_to_location").arg(modelData.line.direction) || ""

            elide: Text.ElideRight
            color: item.style.walkColor
            font: item.style.walkFont
        }

        // walk on the middle of the journey
        Image {
            id: walkDest

            visible: isWalk
            source: "../../../images/icon-walking.png"

            anchors.left: parent.left
            anchors.leftMargin: middlePosition

            anchors.verticalCenter: parent.verticalCenter
        }

        MouseArea {
            id: mouseAreaDest

            anchors.fill: parent

            enabled: !isWalk

            onClicked: openLineDetails()
        }
    }

    // end point - only last element
    Image {
        visible: isLast
        source: getBackgroundSource(realIndex + ((lineDest.visible) ? 2 : 1), mouseAreaEnd.pressed)

        height: item.style.height
        width: parent.width

        fillMode: Image.TileHorizontally

        Image {
            id: walkEnd
            visible: isLast && !isFirst && isWalk
            source: "../../../images/icon-walking.png"

            anchors.right: titleEnd.left
            anchors.rightMargin: 5
            anchors.verticalCenter: parent.verticalCenter
        }

        // The last step title
        Text {
            id: titleEnd

            text: walkEnd.visible ? getWalkString(modelData) : toTitle

            anchors {
                left: parent.left
                leftMargin: middlePosition + (walkEnd.visible ? 24 : 0)
                right: parent.right
                rightMargin: isWalk ? 45 : 10
                bottom: parent.bottom
                bottomMargin: 23
                top: parent.top
                topMargin: walkEnd.visible ? 0 : 23
            }

            color: walkEnd.visible ? item.style.walkColor : item.style.color
            font: walkEnd.visible ? item.style.walkFont : item.style.font
            elide: walkEnd.visible ? Text.ElideNone : Text.ElideRight
            verticalAlignment: Text.Bottom // let's hope there are not more than two lines
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        }

        // last step title if walk
        Label {
            visible: walkEnd.visible
            text: qsTrId("qtn_pt_journeydetails_to_location").arg(toTitle)

            anchors.bottom: parent.bottom
            anchors.bottomMargin: 3

            anchors.left: titleEnd.left
            anchors.right: titleEnd.right

            color: item.style.hintColor
            font: item.style.hintFont

            elide: Text.ElideRight
        }

        Image {
            id: walkEndMapIcon
            visible: isWalk && isLast
            source: "../../../images/show_on_map_34px.png"

            anchors.right: parent.right
            anchors.rightMargin: 9

            anchors.verticalCenter: parent.verticalCenter
        }


        MouseArea {
            id: mouseAreaEnd

            anchors.fill: parent

            onClicked: {
                if (isLast && isWalk) {
                    openWalkNavigation()
                } else {
                    openStopDetails(true)
                }
            }
        }
    }
}

