import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"

import "../ApplicationModel.js" as App

Page {
    id: journeyDetails
    objectName: "journeyDetailsPage"

    property variant from
    property variant to

    property alias visibleIndex: journeyList.visibleIndex

    title: qsTrId("qtn_pt_journeydetails_title").arg(journeyList.currentIndex + 1).arg(journeyList.count)

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("JourneyDetails");
        }
    }

    function showDetails(from, to, connections, connectionIndex) {
        journeyDetails.from = from;
        journeyDetails.to = to;
        journeyList.model = []; // Workaround to fix PT-417, needs to be retested in newer QT versions than 4.7.4
        journeyList.model = connections;
        journeyList.positionViewAtIndex(connectionIndex, ListView.Center);
        journeyList.savedCurrentItem = connectionIndex;
    }

    function reset() {
        journeyList.model = [];
        journeyDetails.from = null;
        journeyDetails.to = null;
    }

    property real currentTime: Date.now()

    Timer {
        interval: 5000
        running: statusStr === "Active" && System.appInForeground
        repeat: true
        onTriggered: {
            currentTime = Date.now();
        }
    }

    QueryDialog {
        id: walkDialog
        property bool walk: false
        property variant navigate: {}
        titleText: walkDialog.walk ? qsTrId("qtn_pt_journeydetails_walk_title") : qsTrId("qtn_pt_journeydetails_show_on_map_title")

        message: walkDialog.walk ? qsTrId("qtn_pt_journeydetails_walk_text").arg(walkDialog.navigate.name)
                                  : qsTrId("qtn_pt_journeydetails_show_on_map_text").arg(walkDialog.navigate.name)

        acceptButtonText: walkDialog.walk ? qsTrId("qtn_pt_journeydetails_go") : qsTrId("qtn_pt_journeydetails_show") // "Ok"
        rejectButtonText: qsTrId("qtn_pt_nothanks")

        onAccepted: {
            if (System.launchMaps(walkDialog.navigate.name,
                                  walkDialog.navigate.latitude,
                                  walkDialog.navigate.longitude,
                                  walkDialog.walk)) {
                startingMaps.show("starting");
                app.analytics.logEvent("LaunchingMaps", { mode: walkDialog.walk ? "walk" : "showmap" } );
            } else {
                startingMaps.show("error");
                app.analytics.logEvent("LaunchingMaps", { mode: "error" } );
            }
        }
        onRejected: {
            app.analytics.logEvent("LaunchingMaps", { mode: "cancelled" } );
        }

        function start() {
            walk = App.computeDistance(App.currentPosition.location, {"latitude": navigate.latitude, "longitude": navigate.longitude } ) < 3000;
            open(app);
        }
    }

    QueryDialog {
        id: startingMaps
        titleText: walkDialog.titleText
        property string type: "starting"

        acceptButtonText: startingMaps.type === "starting" ? "" : qsTrId("qtn_pt_ok")

        message: startingMaps.type === "starting"
                    ? qsTrId("qtn_pt_journeydetails_navigation_text") // "The maps application is being started and will soon guide you to your chosen target. Please wait."
                    : qsTrId("qtn_pt_journeydetails_navigation_error")

        resources: [ // needs embed because of qtc
            Timer {
                id: hideTimer
                interval: 5000
                onTriggered: {
                    startingMaps.close();
                }
            }
        ]

        function show(config) {
            type = config;
            if (config === "starting") {
                hideTimer.start();
            } else {
                hideTimer.stop();
            }
            open(app);
        }
    }

    Connections {
        // this stabilizes the current item index when the phone/simulator orientation is changed
        target: app
        onInPortraitChanged: {
            if (journeyList.visibleIndex !== journeyList.savedCurrentItem ) {
                journeyList.positionViewAtIndex(journeyList.savedCurrentItem, ListView.Visible);
            }
        }
    }

    ListView {
        id: journeyList

        anchors.fill: parent
        orientation: ListView.Horizontal
        cacheBuffer: (statusStr === "Active") && (horizontalVelocity === 0) ? 10 : 0 // px to each side
        snapMode: ListView.SnapOneItem
        highlightRangeMode: ListView.StrictlyEnforceRange

        onCurrentIndexChanged: console.log("ListView.currentIndex:", currentIndex);

        property int visibleIndex: Math.round(contentX / width)

        // this stabilizes the current item index when the phone/simulator orientation is changed
        property int savedCurrentItem: 0
        onMovingChanged: {
            if (!moving) {
                savedCurrentItem = visibleIndex;
                app.analytics.logEvent("JourneyDetails");
            }
        }

        delegate: JourneyDetails {
            connection: modelData
            parentPageState: journeyDetails.status
            width: journeyList.width + 1
            height: journeyList.height

            totalPages: journeyList.count
            currentPage: index
//            Component.onCompleted: console.log("---> JourneyDetails created for index", index);
        }
    }
}
