import QtQuick 1.0


import "../../qtcomponents"
import "../../components"

// The load more items
Item {
    id: snapper
    z: 200
    anchors.right: parent.left

    width: 100
    height: 80

    property bool enabled: true
    property int timeLineHeight: 30

    signal started();
    signal stopped();

    function finished() {
        stopped();
        state = "";
    }

    Image {
        id: arrow
        y: (timeLineHeight - height) / 2
        asynchronous: true
        anchors {
            right: parent.right
            rightMargin: 5
        }

        source: "../../../images/arrow.png"
        smooth: true
        rotation: visible ? (flickie.contentX < -40 ? Math.min(-3.5 * (flickie.contentX + 40), 180) : 0) : 0

        onRotationChanged: {
            if (snapper.enabled) {
                if (rotation == 180 && !timer.running) {
                    timer.start()
                } else {
                    timer.stop()
                }
            }
        }
    }

    Label {
        id: status
        y: 43
        text: arrow.rotation == 180 ?
                  qsTrId("qtn_pt_routeplanner_earlier_hold") : // "Hold to load earlier"
                  qsTrId("qtn_pt_routeplanner_earlier_drag") // "Drag right to load earlier"
        wrapMode: Text.WordWrap
        anchors.right: parent.right
        anchors.rightMargin: 5
        font.pixelSize: 16
        color: "#333"
        height: 20
        width: 80
        horizontalAlignment: Text.AlignRight
        font.bold: true
        font.wordSpacing: 3
        font.letterSpacing: -1
    }

    BusyIndicator {
        id: progress        
        anchors {
            top: arrow.top
            bottom: arrow.bottom
            horizontalCenter: arrow.horizontalCenter
        }
        width: 24
        visible: false
    }

    Timer {
        id: timer
        interval: 1000
        onTriggered: {
            snapper.state = "loading"
            started();
        }
    }

    states: State {
        name: "loading"

        PropertyChanges {
            target: status
            text: qsTrId("qtn_pt_routeplanner_earlier_loading") // "Loading earlier"
        }

        PropertyChanges {
            target: arrow
            visible: false
        }

        PropertyChanges {
            target: progress
            visible: true
            running: true
        }
    }
}
