import QtQuick 1.0
import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import "../ApplicationModel.js" as App

Page {
    id: page
    objectName: "lineDetailsPage"
    title: qsTrId("qtn_pt_linedetails_title")

    property variant step

    property QtObject style: JourneyDetailsStyle {} // might there should be a generic style object

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("LineDetails");
        }
    }

    function calculateHeight(theStep, height)
    {
        var retHeight = height + 60;
        if (theStep && theStep.hasDelayInfo)
        {
            retHeight += 30;
        }
        return retHeight;
    }

    ListView {
        id: stopList

        anchors.fill: parent
        anchors.bottomMargin: 10

        model: step ? step.stops : undefined

        header: Item {
            height: calculateHeight(step, lineSymbol.destinationElement.paintedHeight)
            anchors {
                left: parent.left
                right: parent.right
            }

            Image {
                id: stationIcon
                anchors {
                    top: parent.top
                    topMargin: 14
                    left: parent.left
                    leftMargin: 45
                }
                width: 34
                source: step ? step.line.transitType.defaultType.iconUri(34) : ""
                fillMode: Image.PreserveAspectFit
                smooth: true
                z: 10
            }

            LineItem {
                id: lineSymbol
                anchors {
                    top: parent.top
                    topMargin: 16
                    left: stationIcon.right
                    leftMargin: 11
                    right: parent.right
                    rightMargin: 16
                }
                threshold: 1
                //need those ugly default values to get rid of warnings in LineItem.qml
                line: step ? step.line : {
                                 direction: "",
                                 name: "",
                                 lineScheme: {
                                     color: "#000",
                                     shape: "",
                                     outlineColor: "#000"
                                 },
                                 transitType: {
                                     shape: ""
                                 }
                             }
                smooth: true
            }

            Label {
                id: lateLabel
                anchors {
                    top: lineSymbol.bottom
                    topMargin: 4
                    left: lineSymbol.left
                    leftMargin: 4
                }
                visible: step ? step.hasDelayInfo : false
                text: step ? (step.departureDiff ? qsTrId("qtn_pt_linedetails_late").arg(step.departureDiff / 60000) : qsTrId("qtn_pt_linedetails_on_time")) : ""
                font.pixelSize: 16
                color: step ? (step.departureDiff ? "#ba360e" : "#178900") : "#000"
            }

            Rectangle {
                id: lineStart
                anchors {
                    top: stationIcon.bottom;
                    topMargin: -4
                    left: parent.left
                    leftMargin: 58
                }

                width: 9
                height: lineSymbol.height + 60
                color: step ? step.line.lineScheme.color : "#000"
                opacity: 0.4
            }

        }

        footer: Item {
            height: destination.y + 70 // destination.height // binding loop ?
            anchors {
                left: parent.left
                right: parent.right
            }

            Rectangle { // the delegate must draw the line as well .. here we just extend the line. might circle repositioning
                id: lineEnd
                anchors {
                    top: parent.top
                    topMargin: -100
                    left: parent.left
                    leftMargin: 58
                }
                width: 9
                height: 20 + 100
                color: step ? step.line.lineScheme.color : "#000"
                opacity: 0.4
                z: -1
            }

            Triangle {
                id: triangle
                anchors {
                    top: lineEnd.bottom
                    horizontalCenter: lineEnd.horizontalCenter
                }
                width: 32
                height: 20
                color: step ? step.line.lineScheme.color : "#000"
                opacity: 0.4
            }

            Text {
                id: destination
                anchors {
                    top: triangle.bottom
                    left: parent.left
                    leftMargin: 48
                    right: parent.right
                    rightMargin: 24
                }
                text: step ? step.line.direction : ""
                wrapMode: Text.Wrap
                color: page.style.color
                font: page.style.font
            }
        }

        delegate: Item {
            id: stopItem

            width: stopList.width
            height: stationName.height + (isLast ? -5 : 30)

            property bool isFirst: index === 0
            property bool isLast: index + 1 === stopList.model.length

            Image {
                id: walkStart
                anchors {
                    right: lineColor.left
                    rightMargin: 14
                }
                source: isFirst ?  "../../../images/journeyplanner/walk_dark.png" :
                    isLast ?  "../../../images/journeyplanner/walk_dark_back.png"
                        : ""
                opacity: 0.7
            }

            Rectangle {
                id: lineColor
                anchors {
                    top: parent.top
                    topMargin: isFirst ? 8 : 0
                    left:parent.left
                    leftMargin: 58
                }
                width: 9
                height: isLast ? 16 : parent.height
                color: step.line.lineScheme.color
            }

            Circle {
                id: lineDot
                anchors {
                    top: parent.top
                    topMargin: 7
                    left:parent.left
                    leftMargin: 54
                }
                height: 17
                width: 17
                color: step.line.lineScheme.color
                smooth: true
            }

            Text {
                id: stationName
                anchors {
                    top: parent.top
                    left:lineColor.right
                    leftMargin: 14
                    right: time.left
                    rightMargin: 10
                }
                text: modelData.station.displayName
                wrapMode: Text.Wrap
                color: page.style.color
                font: page.style.font
            }

            DateTime {
                id: time
                anchors {
                    top: parent.top
                    topMargin: 5
                    right:parent.right
                    rightMargin: 14
                }
                datetime: isFirst ? modelData.departure : modelData.arrival
                format: "time"
                color: "#4e4e4e"
                font {
                    pixelSize: page.style.timeFont.pixelSize
                    strikeout: !!step.departureDiff
                }
                opacity: step.departureDiff ? 0.5 : 1
                visible: step.timetableBased && datetime
            }

            DateTime {
                anchors {
                    top: time.bottom
                    right:time.right
                }
                datetime: modelData.arrival + step.departureDiff
                format: "time"
                color: "#ba360e"
                font: page.style.timeFont
                visible: time.visible && !!step.departureDiff
            }
        }
    }
}
