import QtQuick 1.0


import "../../qtcomponents"
import "../../components"

// The load more items
Item {
    id: snapper
    z: 200
    anchors.left: parent.right

    width: 100
    height: 80

    property bool enabled: true
    property int timeLineHeight: 30

    signal started();
    signal stopped();

    function finished() {
        stopped();
        state = "";
    }

    Image {
        id: arrow
        y: (timeLineHeight - arrow.height) / 2
        asynchronous: true
        anchors.left: parent.left
        anchors.leftMargin: 5

        source: "../../../images/arrow.png"
        smooth: true
        rotation: visible ? (flickie.contentX > flickie.contentWidth - flickie.width + 40 ?
                                 Math.max(180 + 3.5 * (flickie.contentWidth - flickie.contentX - flickie.width + 40), 0) : 180) : 180

        onRotationChanged: {
            if (snapper.enabled) {
                if (rotation == 0 && !timer.running) {
                    timer.start()
                } else {
                    timer.stop()
                }
            }
        }
    }

    Label {
        id: status
        y: 43
        text: arrow.rotation == 0 ?
                  qsTrId("qtn_pt_routeplanner_later_hold") : // "Hold to load later"
                  qsTrId("qtn_pt_routeplanner_later_drag")  // "Drag left to load later"
        wrapMode: Text.WordWrap
        anchors.left: parent.left
        anchors.leftMargin: 5
        font.pixelSize: 16
        color: "#333"
        height: 20
        width: 80
        horizontalAlignment: Text.AlignLeft
        font.bold: true
        font.wordSpacing: 3
        font.letterSpacing: -1
    }

    BusyIndicator {
        id: progress
        anchors {
            top: arrow.top
            bottom: arrow.bottom
            horizontalCenter: arrow.horizontalCenter
        }
        width: 24
        visible: false
    }

    Timer {
        id: timer
        interval: 1000
        onTriggered: {
            snapper.state = "loading"
            started();
        }

    }

    states: State {
        name: "loading"

        PropertyChanges {
            target: status
            text: qsTrId("qtn_pt_routeplanner_later_loading") // "Loading later"
        }

        PropertyChanges {
            target: arrow
            visible: false
        }

        PropertyChanges {
            target: progress
            visible: true
            running: true
        }
    }
}
