import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"

import "../LandingPage"
import ".."

import "../ApplicationModel.js" as App
import "RoutePlannerPage.js" as Logic

Page {
    id: routePlanner
    objectName: "routePlannerPage"

    title: qsTrId("qtn_pt_routeplanner_title")

    property variant journeys
    property variant from
    property variant to
    // TODO: refactor to have simple from & to values mapped to input fields
    property alias fromValue: fromInput.value
    property alias toValue: toInput.value
    property variant when
    property variant lastSearchTime
    property bool arrival
    property variant allowedTypes
    property variant info: {} // additional information cache

    property bool filter: false // contains the current filter informations
    property bool ignoreInputValueChanges: false
    property bool isSimpleRouting: listRef.visible && listRef.list && journeys && !listRef.list.showAbsoluteTimes || false

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("JourneyPlanner");
        } else if ("Active" === statusStr) {
            if (listRef.list && listRef.list.needsTimeScaleUpdate) {
                listRef.list.updateTimeScale();
            }
            // autoselect empty input fields
            if (!fromInput.isSet() && !toInput.selected) fromInput.selected = true;
            if (!toInput.isSet() && !fromInput.selected) toInput.selected = true;
            // load journeys of we have all data
            if (!journeys) {
                if (routePlanner.filter) {
                    Logic.updateInput(undefined, routePlanner.when, routePlanner.arrival, routePlanner.allowedTypes);
                } else {
                    Logic.updateInput();
                }
            }
        } else if ("Deactivating" === statusStr) {
            if (App.queries.connection && App.queries.connection.status === 2) {
                App.queries.connection.cancel();
                loadingIndicator.visible = false;
                errorNotification.errorCode = QueryResult.NoError;                
            }
            fromInput.cancelSearch();
            toInput.cancelSearch();
        }
        if (listRef.list) {
            listRef.list.pageStatusStr = statusStr;
        }
    }

    tools: ToolBarLayout {
        BackToolButton {
            id: backButton

            function clickHandler() {
                if (!toInput.selected && !fromInput.selected) {
                    if (app.pageStack.depth > 1) {
                        app.pageStack.pop();
                    } else {
                        app.quit();
                    }
                } else {
                    if (fromInput.selected) {
                        fromInput.inputText = fromInput.preText;
                    }
                    if (toInput.selected) {
                        toInput.inputText = toInput.preText;
                    }
                    toInput.selected = fromInput.selected = false;
                }
            }
        }

        ToolIcon {
            objectName: "optionsBtn"
            id: optionsButton
            property bool v: !isSimpleRouting
            iconSource: v ? "../../../images/toolbar/settings" + (routePlanner.filter ? "-active" : "") + ".png" : ""
            enabled: v

            onClicked: {
                var page = pageStack.push(timePickerPage);
                if (!routePlanner.filter) page.reset();
            }
        }
    }

    ViewHeading {
        id: headerBar
        contentHeight: headerBarContent.height + 10 + (srHint.visible ? srHint.height + 7 : 0)
        width: parent.width

        Flow {
            id: headerBarContent
            x: 10;
            y: 10;
            spacing: 10
            width: parent.width - 20;

            AutoCompletionInput {
                id: fromInput

                Rectangle {
                    id: fromInputHighlight
                    anchors {
                        fill: fromInput
                        topMargin: -10
                        rightMargin: app.inPortrait ? -10 : -5
                        leftMargin: -10
                        bottomMargin: app.inPortrait ? -6 : -9
                    }
                    z: -1
                    color: "#1080DD"
                    opacity: fromInput.selected ? 1 : 0
                    Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                }
                Text {
                    id: fromInputHint
                    text: qsTrId("qtn_pt_routeplanner_from")
                    color: "white"
                    anchors {
                        left: parent.left
                        leftMargin: fromInput.selected ? 0 : (-paintedWidth - 10)
                        verticalCenter: parent.verticalCenter
                    }
                    Behavior on anchors.leftMargin { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                    opacity: fromInput.selected ? 1 : 0
                    Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                }

                inputMarginLeft: fromInputHint.paintedWidth + 10 + fromInputHint.anchors.leftMargin
                width: app.inPortrait ? headerBarContent.width : headerBarContent.width/2 - 5
                placeholderText: qsTrId("qtn_pt_routeplanner_input_watermark")
                extraMarginLeft: fromInput.isCurrentPosition || toInput.isCurrentPosition

                onSelectedChanged: {
                    if (selected) {
                        toInput.leaveKeyboardOpen = true;
                        toInput.selected = false;
                        toInput.leaveKeyboardOpen = false;
                        gpsWaitingIndicator.hide();
                        if (App.queries.connection) {
                            Logic.reset();
                        }
                        errorNotification.errorCode = QueryResult.NoError;
                    }
                }
                listArea: overlay
                property string preText: ""
                onValueChanged: {
                    if (value && !isCurrentPosition) {
                        preText = text;
                    }
                    if (routePlanner.filter) {
                        Logic.updateInput(fromInput, routePlanner.when, routePlanner.arrival, routePlanner.allowedTypes);
                    } else {
                        routePlanner.filter = false;
                        Logic.updateInput(fromInput);
                    }
                }
                property string oldText: text
                onTextChanged: {
                    if (oldText !== "" && text === "")
                        routePlanner.filter = false;
                    oldText = text;
                }
                value: App.currentPosition.location
            }

            AutoCompletionInput {
                id: toInput

                Rectangle {
                    id: toInputHighlight
                    anchors {
                        fill: toInput
                        topMargin: app.inPortrait ? -6 : -10
                        rightMargin: -10
                        leftMargin: app.inPortrait ? -10 : -5
                        bottomMargin: -9
                    }
                    z: -1
                    color: "#1080DD"
                    opacity: toInput.selected ? 1 : 0
                    Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                }

                Text {
                    id: toInputHint
                    text: qsTrId("qtn_pt_routeplanner_to")
                    color: "white"
                    anchors {
                        left: parent.left
                        leftMargin: toInput.selected ? 0 : (-paintedWidth - 10)
                        verticalCenter: parent.verticalCenter
                    }
                    Behavior on anchors.leftMargin { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                    opacity: toInput.selected ? 1 : 0
                    Behavior on opacity { NumberAnimation { duration: 500; easing.type: Easing.OutQuad } }
                }

                inputMarginLeft: toInputHint.paintedWidth + 10 + toInputHint.anchors.leftMargin
                width: fromInput.width;
                placeholderText: qsTrId("qtn_pt_routeplanner_input_watermark")
                extraMarginLeft: fromInput.isCurrentPosition || toInput.isCurrentPosition
                onSelectedChanged: {
                    if (selected) {
                        fromInput.leaveKeyboardOpen = true;
                        fromInput.selected = false;
                        fromInput.leaveKeyboardOpen = false;
                        gpsWaitingIndicator.hide();
                        if (App.queries.connection) {
                            Logic.reset();
                        }
                        errorNotification.errorCode = QueryResult.NoError;
                    }
                }
                listArea: overlay
                property string preText: ""
                onValueChanged: {
                    if (value && !isCurrentPosition) {
                        preText = text;
                    }
                    if (routePlanner.filter) {
                        Logic.updateInput(toInput, routePlanner.when, routePlanner.arrival, routePlanner.allowedTypes);
                    } else {
                        Logic.updateInput(toInput);
                    }
                }
                property string oldText: text
                onTextChanged: {
                    if (oldText !== "" && text === "")
                        routePlanner.filter = false;
                    oldText = text;
                }
            }
        }

        ViewHeadingText {
            id: srHint
            anchors {
                top: headerBarContent.bottom
                topMargin: 10
                left: parent.paddingItem.left
                right: parent.paddingItem.right
            }
            text: qsTrId("qtn_pt_routeplanner_simpleroutinghint")
            visible: isSimpleRouting
        }

        Rectangle {
            anchors {
                top: headerBarContent.bottom
                topMargin: 7
                left: parent.left
                right: parent.right
            }
            color: "#3B3B3B"
            height: 1
            visible: srHint.visible
        }

        Rectangle {
            id: bottomHairLine
            anchors {
                top: headerBarContent.bottom
                topMargin: 8
                left: parent.left
                right: parent.right
            }
            color: "#B6B6B6"
            height: 1
            visible: srHint.visible
        }
    }

    Item {
        id: overlay
        anchors.top: headerBar.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
    }

    PageCache {
        id: timePickerPage

        //property Page page;
        component: Component {
            TimePickerPage {
                id: timePicker
                onTimePicked: {
                    routePlanner.filter = true;
                    routePlanner.when = date;
                    routePlanner.allowedTypes = allowedTypes;
                    routePlanner.arrival = arrival;
                    if (from && to) {
                        Logic.query(from, to, date, arrival, allowedTypes, routePlanner.info);
                    }
                }
            }
        }
    }

    Loader {
        property variant routePlanner: routePlanner
        property alias list: listRef.item
        property alias timePickerPage: timePickerPage

        id: listRef

        // reference size for JourneyCalendar
        anchors {
            top: headerBar.bottom
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        opacity: !!routePlanner.journeys && !fromInput.selected && !toInput.selected
                 ? 1 : 0
        Behavior on opacity { NumberAnimation { duration: 250 } }

        property variant timeStarted: 0
        onStatusChanged: {
            if (Loader.Ready === status) {
                console.log("Loaded JourneyCalendarSubpage in", timeStarted, System.currentTime, (System.currentTime - timeStarted) + "ms");
            }
        }
        function load() {
            if (listRef.source == "") {
                timeStarted = System.currentTime;
                listRef.source = "JourneyCalendarSubpage.qml"
            }
        }
    }

    Item {
        anchors {
            top: headerBar.bottom
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        LoadingIndicator {
            id: loadingIndicator
            anchors.verticalCenterOffset: app.inPortrait ? -15 : 0
            visible: false
        }

        LoadingIndicator {
            id: gpsWaitingIndicator

            anchors.verticalCenterOffset: app.inPortrait ? -15 : 0
            text: qsTrId("qtn_pt_routeplanner_gps_waiting")
            visible: false

            function positionChanged() {
                Logic.query(fromInput.value, toInput.value);
                hide();
            }

            function show() {
                App.currentPosition.positionChanged.connect(positionChanged);
                visible = true;
            }

            function hide() {
                visible = false;
                App.currentPosition.positionChanged.disconnect(positionChanged);
            }
        }

        RoutingErrorNotification {
            id: errorNotification

            onRetryClicked: {
                // retry
                Logic.query(from, to);
                errorCode = QueryResult.NoError;
            }
        }
    }
}
