import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"

import "../LandingPage"
import ".."


import "../ApplicationModel.js" as App

ErrorNotification {
    id: errorNotification
    visible: false
    anchors {
        left: parent.left
        right: parent.right
        verticalCenter: parent.verticalCenter
        verticalCenterOffset: app.inPortrait ? -15 : 0
    }

    font { pixelSize: app.inPortrait ? 24: 20 }

    property int errorCode: QueryResult.NoError
    property bool networkError: (errorCode & QueryResult.NetworkError) === QueryResult.NetworkError

    states: [
        State {
            name: "no_connections"
            when: errorNotification.errorCode === QueryResult.NoError && routePlanner.journeys && routePlanner.journeys.length === 0
            PropertyChanges {
                target: errorNotification

                icon: "../../../images/errorpage/icon_no_routes.png"
                text: qsTrId("qtn_pt_routeplanner_noconnections")
                visible: true
            }
        },
        State {
            name: "network_error"
            when: errorNotification.networkError
            PropertyChanges {
                target: errorNotification

                icon: "../../../images/errorpage/icon_no_internet.png"
                text: qsTrId("qtn_pt_error_hafas_connections").arg(app.getErrorText(errorCode));
                visible: true
                retryButton: true
            }
        },
        State {
            name: "no_data_error"
            when: errorNotification.errorCode == QueryResult.NoDataAvailable
            PropertyChanges {
                target: errorNotification

                icon: "../../../images/errorpage/icon_no_data.png"
                text: qsTrId("qtn_pt_error_hafas_connections").arg(app.getErrorText(errorCode));
                visible: true
                regionsButton: true
            }
        },
        State {
            name: "other_error"
            when: !errorNotification.networkError && (errorNotification.errorCode !== QueryResult.NoError)
            PropertyChanges {
                target: errorNotification

                icon: "../../../images/errorpage/icon_no_routes.png"
                text: qsTrId("qtn_pt_error_hafas_connections").arg(app.getErrorText(errorCode));
                visible: true
                regionsButton: errorCode === QueryResult.NoDataAvailable
            }
        }

    ]
}
