import QtQuick 1.0



import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Page {
    objectName: "stationDetailsPage"

    property variant station
    property variant line
    title: qsTrId("qtn_pt_stationdetails_title")

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("StationDetails");
        }
    }

    Flickable {
        anchors.fill: parent
        contentHeight: col.height

        Column {
            id: col
            x: 10
            width: parent.width - 20

            ViewHeading {
                anchors { left: parent.left; leftMargin: -10; right: parent.right; rightMargin: -10; }
                contentHeight: stationName.height
                ViewHeadingText {
                    id: stationName
                    anchors { left: parent.paddingItem.left; right: parent.paddingItem.right; verticalCenter: parent.paddingItem.verticalCenter }
                    text: station ? station.displayName : ""
                }
            }


            Item { width: 10; height: 10 }

            Item {
                height: 34
                anchors { left: parent.left; right: parent.right }

                Image {
                    id: transportType
                    width: 34
                    height: 34
                    source: (line && line.lineScheme.iconUri(34)) || ""
                    visible: status == Image.Ready
                }

                Rectangle {
                    color: line ? line.lineScheme.color || "#000" : "#000"
                    anchors.left: transportType.right
                    anchors.leftMargin: 7
                    anchors.right: parent.right
                    height: 26
                    anchors.verticalCenter: parent.verticalCenter

                    border.color: line ? line.lineScheme.outlineColor : "#000"
                    border.width: line && line.lineScheme.outlineColor ? 2 : 0

                    Label {
                        anchors.fill: parent
                        anchors.leftMargin: 5
                        anchors.rightMargin: 5

                        color: line? line.lineScheme.textColor || "#fff" : "#fff"
                        text: line ? line.name || "" : ""

                        font.pixelSize: 18
                        font.bold: true

                        verticalAlignment: "AlignVCenter"
                        elide: Text.ElideRight
                    }
                }
            }

            Item {
                height: 20
                width: 10
            }

            Row {
                height: 40
                spacing: 10
                visible: station ? !!station.escalator : false

                Image {
                    source: "../../../images/escalator_small.png"
                    asynchronous: true
                }

                Label {
                    text: qsTrId("qtn_pt_stationdetails_escalators") // "Escalators"
                    font.pixelSize: 18
                    anchors.verticalCenter: parent.children[0].verticalCenter
                }
            }

            Row {
                height: 40
                spacing: 10
                visible: station ? !!station.elevator: false

                Image {
                    source: "../../../images/elevator_small.png"
                    asynchronous: true
                }

                Label {
                    text: qsTrId("qtn_pt_stationdetails_elevators") // "Elevators"
                    font.pixelSize: 18
                    anchors.verticalCenter: parent.children[0].verticalCenter
                }
            }

            Row {
                height: 40
                spacing: 10
                visible: station ? !!station.blindguidinglines: false
                Image {
                    source: "../../../images/blind_small.png"
                    asynchronous: true
                }

                Label {
                    text: qsTrId("qtn_pt_stationdetails_blindguidinglines") // "Blind guidinglines"
                    font.pixelSize: 18
                    anchors.verticalCenter: parent.children[0].verticalCenter
                }
            }

            Row {
                height: 40
                spacing: 10
                visible: line ? !!line.barrierFree : false
                Image {
                    source: "../../../images/barrierfree_small.png"
                    asynchronous: true
                }

                Label {
                    text: qsTrId("qtn_pt_stationdetails_barrierfree") // "Barrier free"
                    font.pixelSize: 18
                    anchors.verticalCenter: parent.children[0].verticalCenter
                }
            }

            Row {
                height: 40
                spacing: 10
                visible: line ? !!line.bicyclesAllowed : false
                Image {
                    source: "../../../images/bicycle_small.png"
                    asynchronous: true
                }

                Label {
                    text: qsTrId("qtn_pt_stationdetails_bicyclesallowed") // "Bicycles allowed"
                    font.pixelSize: 18
                    anchors.verticalCenter: parent.children[0].verticalCenter
                }
            }
        }
    }
}
