import QtQuick 1.0

import com.nokia.pt 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Page {
    id: timePicker
    objectName: "timePickerPage"
    title: qsTrId("qtn_pt_timepicker_title")

    signal timePicked(date date, bool arrival, variant allowedTypes)
    property bool arrival: false
    property variant transportTypeFilter

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("TimePicker");
        } else if ("Active" === statusStr) {
            transportTypeItem.selected = false;
        }
    }

    function reset() {
        transportTypeFilter = undefined;
        arrival = false;
        departArrive.checkedButton = btnDepart;
        updateTime();
    }

    function updateTime() {
        var now = new Date();
        if (!days.items) {
            var dayItems = [];
            for (var d = -3; d <= 14; d++) {
                if (d === 0) {
                    dayItems.push(qsTrId("qtn_pt_journeydetails_today"));
                } else if (d === 1) {
                    dayItems.push(qsTrId("qtn_pt_journeydetails_tomorrow"));
                } else {
                    var itemTime = new Date(now.getTime());
                    itemTime.setDate(itemTime.getDate() + d)
                    dayItems.push(System.formatDate(itemTime));
                    if (d === -3) {
                        days.first = itemTime;
                    }
                }

            }
            days.items = dayItems;
        }
        if (!hours.items) {
            var hourItems = [];
            var h;
            if (System.isAmPm()) {
                for (h = 1; h <= 12; h++) {
                    hourItems.push(h);
                }
            } else {
                for (h = 0; h <= 23; h++) {
                    hourItems.push(h);
                }
            }
            hours.items = hourItems;
        }
        if (!minutes.items) {
            var minuteItems = [];
            for (var m = 0; m <= 59; m++) {
                minuteItems.push((m < 10 ? "0" : "") + m);
            }
            minutes.items = minuteItems;
        }

        select(now)
    }

    function select(date) {
        days.selectedIndex = (date.getTime() - days.first.getTime()) / (24 * 3600000);
        if (System.isAmPm()) {
            var amPmHours = parseInt(System.formatDateTime(date, "h ap").datetime, 10);
            hours.selectedIndex = amPmHours - 1;
            ampm.selectedIndex = date.getHours() < 12 ? 0 : 1;
        } else {
            hours.selectedIndex = date.getHours();
        }
        minutes.selectedIndex = date.getMinutes();
    }

    Flickable {
        anchors.fill: parent

        contentWidth: width
        contentHeight: transportTypeItem.y + transportTypeItem.height

        ButtonRow {
            id: departArrive
            anchors {
                top: parent.top
                topMargin: 15
                left: parent.left
                leftMargin:  15
                right: parent.right
                rightMargin: 15
            }
            exclusive: true
            height: btnDepart.height

            Button {
                id: btnDepart
                text: qsTrId("qtn_pt_timepicker_departure") //"Depart"
                onClicked: arrival = false
            }
            Button {
                id: btnArrive
                text: qsTrId("qtn_pt_timepicker_arrival") //"Arrive"
                onClicked: arrival = true
            }
            onCheckedButtonChanged: checkedButton = arrival ? btnArrive : btnDepart
        }

        Rectangle {
            id: hairline
            anchors {
                top: departArrive.bottom
                topMargin: 15
                bottomMargin: 15
                left: parent.left
                right: parent.right
            }
            height: 1
            color: "white"
        }

        Item {
            id: dateTimeTumbler
            anchors {
                top: hairline.bottom
                topMargin: 15
                left: parent.left
                leftMargin: 15
                right: parent.right
                rightMargin: app.inPortrait ? 15 : 180
            }
            height: tumbler.implicitHeight

            Tumbler {
                id: tumbler
                anchors.fill: parent
                columns: [
                    TumblerColumn {
                        id: days
                        property variant first
                        privateLoopAround: false
                        Component.onCompleted: {
                            if (days.privateTextAlignment) {
                                if (System.rightToLeft) {
                                    privateTextAlignment = Text.AlignRight;
                                } else {
                                    privateTextAlignment = Text.AlignLeft;
                                }
                            }
                        }
                        recommendedWidth: dateTimeTumbler.width - hours.width - minutes.width - ampm.width
                    },
                    TumblerColumn {
                        id: hours
                        recommendedWidth: app.inPortrait ? (ampm.visible ? 50 : 60) : 70
                    },
                    TumblerColumn {
                        id: minutes
                        recommendedWidth: hours.width
                    },
                    TumblerColumn {
                        id: ampm
                        recommendedWidth: visible ? 60 : 0
                        items: [
                            qsTrId("qtn_pt_timepicker_am"), //"AM"
                            qsTrId("qtn_pt_timepicker_pm")  //"PM"
                        ]
                        privateLoopAround: false
                        visible: System.isAmPm()
                    }
                ]
            }
        }

        ButtonRow {
            id: timeShortCutsPortrait
            anchors {
                top: dateTimeTumbler.bottom
                topMargin: 15
                left: dateTimeTumbler.left
                right: dateTimeTumbler.right
            }
            exclusive: false
            visible: app.inPortrait
            Button {
                id: btnNowPortrait
                font { pixelSize: fontSize }
                text: qsTrId("qtn_pt_timepicker_now")
                onClicked: select(new Date());
            }
            Button {
                id: btn15minPortrait
                font: btnNowPortrait.font
                text: qsTrId("qtn_pt_timepicker_in_15min")
                onClicked: {
                    var date = new Date();
                    date.setMinutes(date.getMinutes() + 15);
                    select(date);
                }
            }
            Button {
                id: btn60minPortrait
                font: btnNowPortrait.font
                text: qsTrId("qtn_pt_timepicker_in_60min")
                onClicked: {
                    var date = new Date();
                    date.setMinutes(date.getMinutes() + 60);
                    select(date);
                }
            }
        }

        Column {
            id: timeShortCutsLandscape
            anchors {
                top: dateTimeTumbler.top
                left: dateTimeTumbler.right
                leftMargin: 24
                right: parent.right
                rightMargin: 24
            }
            spacing: 16
            visible: !app.inPortrait
            Button {
                id: btnNowLandscape
                anchors {
                    left: parent.left
                    right: parent.right
                }
                font { pixelSize: fontSize }
                text: qsTrId("qtn_pt_timepicker_now")
                onClicked: select(new Date());
            }
            Button {
                id: btn15minLandscape
                anchors {
                    left: parent.left
                    right: parent.right
                }
                font: btnNowLandscape.font
                text: qsTrId("qtn_pt_timepicker_in_15min")
                onClicked: {
                    var date = new Date();
                    date.setMinutes(date.getMinutes() + 15);
                    select(date);
                }
            }
            Button {
                id: btn60minLandscape
                anchors {
                    left: parent.left
                    right: parent.right
                }
                font: btnNowLandscape.font
                text: qsTrId("qtn_pt_timepicker_in_60min")
                onClicked: {
                    var date = new Date();
                    date.setMinutes(date.getMinutes() + 60);
                    select(date);
                }
            }
        }

        // calculate flexible font size of segmented button
        property int buttonWith: Math.max(btnNowShadow.paintedWidth, btn15minShadow.paintedWidth, btn60minShadow.paintedWidth);
        Text {
            id: btnNowShadow
            visible: false
            font: btnNowPortrait.font
            text: btnNowPortrait.text
        }
        Text {
            id: btn15minShadow
            visible: false
            font: btn15minPortrait.font
            text: btn15minPortrait.text
        }
        Text {
            id: btn60minShadow
            visible: false
            font: btn60minPortrait.font
            text: btn60minPortrait.text
        }
        Component.onCompleted: {
            btnNowPortrait.font.pixelSize =  btnNowLandscape.font.pixelSize =
                    Math.max(15, Math.min(18, Math.round(77*18 / buttonWith)));
        }

        ListItem {
            id: hairlineBottom
            anchors {
                top: app.inPortrait ? timeShortCutsPortrait.bottom : dateTimeTumbler.bottom
                topMargin: 15
                left: parent.left
                right: parent.right
            }
            height: 1
        }

        ListItem {
            id: transportTypeItem
            anchors {
                top: hairlineBottom.bottom
                left: parent.left
                right: parent.right
            }

            subItemIndicator: true
            contentHeight: transportTypeText.height

            ListItemText {
                id: transportTypeText
                anchors {
                    left: parent.paddingItem.left
                    right: parent.paddingItem.right
                    verticalCenter: parent.paddingItem.verticalCenter
                }

                wrapMode: Text.WrapAtWordBoundaryOrAnywhere

                //TODO: Use dynamic data
                text: transportTypeItem.x(transportTypeFilter)
            }

            function x(filter) {
                var res = [];
                var filterActive = false;
                for (var key in filter) {
                    if (filter[key]) {
                        res.push(qsTrId("qtn_pt_ttdropdown_transportmode_%1".arg(key)));
                    } else {
                        filterActive = true;
                    }
                }
                return (filterActive && res.join(", ")) || qsTrId("qtn_pt_ttdropdown_transportmode_all");
            }

            onClicked: {
                selected = true;
                var page = transportTypeFilterPage;
                page.metaInfo = [];
                transportTypeFilter = transportTypeFilter || createDefaultFilter(internal.metaInfo);
                page.filter = transportTypeFilter;
                page.metaInfo = internal.metaInfo;
                var closedHandler = function() {
                    page.closed.disconnect(closedHandler);
                    if (page.result) {
                        transportTypeFilter = page.filter;
                    }
                }
                page.closed.connect(closedHandler);
                pageStack.push(page);
            }

            function createDefaultFilter(metaInfo) {
                var filter = {};
                metaInfo.forEach(function(item) { filter[item.code] = true; });
                return filter;
            }
        }
    }

    QtObject {
        id: internal
        property variant metaInfo: getMetaInfo()
        function getMetaInfo() {
            //TODO: Use dynamic data
            return [
             {iconUri: "../../packages/__default__/images/type-bus-34px.png", code: Line.Bus}, // "Bus"
             {iconUri: "../../packages/__default__/images/type-regional-rail-34px.png", code: Line.SuburbanRail}, // "S Bahn"
             {iconUri: "../../packages/__default__/images/type-city-metro-34px.png", code: Line.Subway}, // "Underground"
             {iconUri: "../../packages/__default__/images/type-ferry-34px.png", code: Line.Ferry}, // "Ferry"
             {iconUri: "../../packages/__default__/images/type-light-rail-34px.png", code: Line.Tram}, // "Tram"
             {iconUri: "../../packages/__default__/images/type-train-34px.png", code: Line.RegionalRail}, // "Regional Train"
             {iconUri: "../../packages/__default__/images/type-train-34px.png", code: Line.InterRegionRail}] // "Train"
           }
    }

    TransportTypeFilterPage {
        id: transportTypeFilterPage

        onClosed: {
            if (result) {
                var arr = [];
                for (var key in filter) {
                    if (filter[key]) {
                        arr.push(key);
                    }
                }

                selectedFilter = arr;
            }
        }

        property variant selectedFilter
    }


    tools: ToolBarLayout {

        BackToolButton {
            onClicked: {
                result = false;
                closed();
            }
        }

        ToolIcon {
            objectName: "okBtn"
            iconId: "toolbar-done"
            onClicked: {
                var date = new Date(days.first);
                date.setDate(date.getDate() + days.selectedIndex);
                date.setMinutes(minutes.selectedIndex);
                date.setHours(
                    System.isAmPm()
                        ? hours.selectedIndex + 1 % 12 + ampm.selectedIndex * 12
                        : hours.selectedIndex);

                // TODO: Fix type list
                timePicked(date, departArrive.checkedButton === btnArrive, transportTypeFilterPage.selectedFilter);
                pageStack.pop()
            }
        }
    }

    Component.onCompleted: {
       updateTime();
    }
}

