import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Page {
    id: checkinHistory
    objectName: "checkinHistoryPage"

    title: "History"

    signal manualCheckoutClicked (int sessionId);

    property int showManualCheckoutTime: 90 * 60 // production: 90 * 60

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
//            app.analytics.logEvent("CheckinHistory");
        }
    }

    property variant manualCheckoutPage
    onManualCheckoutClicked: { /* sessionId */
        var sesId = sessionId; // save arg into scope
        console.log("manualCheckoutClicked", sessionId);
        manualCheckoutPage = App.pushPage(pageStack, Qt.resolvedUrl("ManualCheckoutPage.qml"), {}, function() {
                if (manualCheckoutPage.selectedStationId) {
                    App.ticketing.checkout(sesId, manualCheckoutPage.selectedStationId);
                }
                manualCheckoutPage = undefined;
            });
    }

    Connections {
        target: Ticket.available ? Ticket : null
        onTapOut: { /* args: tapId, time */
            if (pageStack.currentPage === manualCheckoutPage) pageStack.pop();
        }
        onTapExpired: { /* args: tapId, time */
            if (pageStack.currentPage === manualCheckoutPage) pageStack.pop();
        }
    }

    Text {
        anchors.centerIn: parent
        visible: !list.count
        text: "Tap history is empty."
    }

    ViewHeading {
        id: headerBar
        contentHeight: headerColumn.height
        Column {
            id: headerColumn
            anchors {
                left: parent.paddingItem.left;
                right: parent.paddingItem.right;
                verticalCenter: parent.paddingItem.verticalCenter
            }
            ViewHeadingText {
                text: "LIRR Ticketing"
                font.pixelSize: 17
            }
            ViewHeadingText {
                text: "Your account"
            }
        }
    }

    ListView {
        id: list
        model: App.ticketing.history
        anchors {
            top: headerBar.bottom;
            bottom: parent.bottom;
            left: parent.left;
            right: parent.right;
        }
        spacing: 0
        clip: true

        section.property: "section"
        section.criteria: ViewSection.FullString
        section.delegate: ListHeading {
            ListItemText {
                anchors.fill: parent.paddingItem
                text: section
            }
        }

        delegate: Item {
            id: item
            height: layout.height + 10
            Behavior on height { NumberAnimation { duration: 250; easing.type: Easing.InOutQuad; } }
            width: parent.width

            property bool isWaiting: 0 === outStatus
            Column {
                id: layout
                anchors {
                    top: parent.top
                    topMargin: 5
                    left: parent.left
                    leftMargin: 8
                    right: parent.right
                    rightMargin: 8
                }
                Item {
                    height: 30
                    width: parent.width
                    Image {
                        anchors {
                            left: parent.left
                            verticalCenter: parent.verticalCenter
                        }
                        source: list.getIconForStatus(inStatus)
                    }
                    DateTime {
                        anchors {
                            left: parent.left
                            leftMargin: 40
                            verticalCenter: parent.verticalCenter
                        }
                        datetime: inTime * 1000
                        format: "time"
                        color: "#999"
                    }
                    Text {
                        anchors {
                            left: parent.left
                            leftMargin: 110
                            right: parent.right
                            rightMargin: 12
                            verticalCenter: parent.verticalCenter
                        }
                        text: inStationName
                        wrapMode: Text.WrapAnywhere
                        elide: Text.ElideRight
                    }
                }
                Item {
                    height: 30
                    width: parent.width
                    Image {
                        anchors {
                            left: parent.left
                            verticalCenter: parent.verticalCenter
                        }
                        source: list.getIconForStatus(outStatus)
                    }
                    DateTime {
                        anchors {
                            left: parent.left
                            leftMargin: 40
                            verticalCenter: parent.verticalCenter
                        }
                        datetime: isWaiting ? System.currentTime - inTime * 1000 : (outTime * 1000)
                        format: isWaiting ? "duration" : "time"
                        color: "#999"
                    }
                    Text {
                        anchors {
                            left: parent.left
                            leftMargin: 110
                            right: parent.right
                            rightMargin: 12
                            verticalCenter: parent.verticalCenter
                        }
                        text: checkoutBtn.visible ? "Missing tap-out"
                                                  : (isWaiting ? "Waiting for tap" : outStationName)
                        wrapMode: Text.WrapAnywhere
                        elide: Text.ElideRight
                        color: checkoutBtn.visible ? "red" : list.getColorForText(outStatus)
                    }
                }
                Button {
                    id: checkoutBtn
                    anchors.horizontalCenter: parent.horizontalCenter
                    visible: (outStatus === App.ticketing.tapOpen && System.currentTime - inTime * 1000 > showManualCheckoutTime * 1000)
                    text: "Check out"
                    onClicked: manualCheckoutClicked(index)
                }
            }
            Rectangle {
                anchors.bottom: parent.bottom
                width: parent.width
                height: 1
                color: "#999"
            }
        }

        function getIconForStatus(status) {
            switch (status) {
                case 0: return "../../../images/ticketing/tap-waiting.png";
                case 1: return "../../../images/ticketing/tap.png";
                case 2: return "../../../images/ticketing/tap-registered.png";
                default: return "../../../images/ticketing/tap-incomplete.png"; // 254, 255
            }
        }

        function getColorForText(status) {
            switch (status) {
                case 0: return "#999";
                case 254:
                case 255: return "red";
                default: return "black";
            }
        }

    }

    ScrollIndicator {
        scrollArea: list
    }
}
