import QtQuick 1.0

import "../../qtcomponents"

import ".."

Page {

    property string errorStr;
    property bool checking;

    tools: ToolBarLayout {
        BackToolButton {
            id: backButton
            visible: !checking
        }
    }

    Connections {
        target: Ticket
        onSetupFinished: {
            checking = false;
            if (error) {
                console.log("Ticket.setupFinished:", error, "showing error message");
                errorStr = error;
            } else {
                console.log("Ticket.setupFinished: ", error, "jump to tutorial");
                pageStack.replace(Qt.resolvedUrl("../Ticketing/Tutorial.qml"));
            }
        }
    }

    Component.onCompleted: {
        checking = true;
        Ticket.setup();
    }

    Timer {
        id: fakeTimer
        interval: 3000
        running: Ticket.simulated
        onTriggered: {
            checking = false;
            console.warn('Ticket.fakeFailing: This is a simulated but epic fail :)');
            // simulating an error
//                if (Math.random() > 0.5) {
                errorStr = "Server issue";
//                } else {
//                    pageStack.replace(Qt.resolvedUrl("../Ticketing/Tutorial.qml"));
//                }
        }
    }

    Item {
        id: page1
        anchors.fill: parent

        opacity: errorStr ? 0 : 1
        visible: opacity > 0

        Behavior on opacity {
            NumberAnimation { duration: 250 }
        }

        BusyIndicator {
             id: loader
             anchors.centerIn: parent
             running: true
             width: 65
             height: 65
        }

        Text {
            anchors {
                bottom: loader.top
                bottomMargin: 30
                horizontalCenter: loader.horizontalCenter
            }
            text: "Checking your account..."
            color: "#282828"
        }
    }

    ErrorCheckingNotification {
        anchors.centerIn: parent
        width: parent.width
        text: errorStr ? "Could not validate your account: " + errorStr : ""

        opacity: text ? 1 : 0
        Behavior on opacity {
            NumberAnimation { duration: 250 }
        }
        visible: opacity > 0

        onRetryClicked: {
            checking = true;
            errorStr = "";
            Ticket.setup();
            Ticket.simulated && fakeTimer.start();
        }
    }
}
