import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import ".."

import "../ApplicationModel.js" as App

Item {
    id: root

    Connections {
        target: Ticket.available ? Ticket : null
        onTapIn: { /* args: tapId, stationId, time, description */
            console.log("Ticketing.tapIn:", tapId, stationId);
            Rumble.success();
            dialog.icon = "../../../images/ticketing/dialog-tap.png"
            dialog.titleText = "Tap-In";
            dialog.message = qsTrId("You tapped in at <b>%1</b>").arg(App.ticketing.getStationNameForId(stationId));
            dialog.open();
        }

        onTapOut: { /* args: tapId, stationId, time, description */
            console.log("Ticketing.tapOut:", tapId, stationId);
            Rumble.success();
            var ride = App.ticketing.getRide();
            if (!ride) { // the logic is out of sync .. so we don't show the dialog and enable nfc again.
                Ticket.readyForNextSession();
                return;
            }
            dialog.icon = "../../../images/ticketing/dialog-tap.png"
            dialog.titleText = "Tap-Out";
            dialog.message = qsTrId("You tapped out at <b>%1</b>. Your trip started %2 ago at %3.")
                    .arg(App.ticketing.getStationNameForId(stationId))
                    .arg(System.formatDuration(new Date().getTime() - ride.inTime * 1000))
                    .arg(ride.inStationName);
            dialog.open();
        }

        onTapFailed: { /* stationId, time, failMessage */
            console.log("Ticketing.tapFailed:",stationId, failMessage);
            Rumble.fail();
            dialog.icon = "../../../images/ticketing/dialog-incomplete.png"
            dialog.titleText = "Tap failed";
            dialog.message = qsTrId("Please tap the touch point to try again.");
            dialog.open();
        }

        onTapExpired: { /* tapId, time */
            console.log("Ticketing.tapExpired:", tapId);
            Rumble.fail();
            dialog.icon = "../../../images/ticketing/dialog-incomplete.png"
            dialog.titleText = "Trip saved as incomplete";
            dialog.message = qsTrId("No valid tap-out was received within three hours.");
            // dia.item.learnMore = true;
            dialog.open();
        }

        onInspectionCompleted: { /* state */
            app.toast.success("You have been inspected");
            Rumble.success();
        }

//        onTapRegistered: {
//        }
    }

    TicketingAcknowledge {
        id: dialog
        parent: root.parent
        onAccepted: Ticket.readyForNextSession()
    }
}
