import QtQuick 1.0

import "../../qtcomponents"
import "../../components"
import ".."
import "../models"

import "../ApplicationModel.js" as App

Page {

    property string selectedStationId: ""

    ViewHeading {
        id: header
        anchors.top: parent.top
        contentHeight: headerText.height
        ViewHeadingText {
            id: headerText
            anchors {
                left: parent.paddingItem.left;
                right: parent.paddingItem.right;
                verticalCenter: parent.paddingItem.verticalCenter
            }
            text: "Check out"
        }
    }

    Text {
        id: text
        anchors {
            top: header.bottom
            left: parent.left
            right: parent.right
            margins: 8
        }
        text: "Manual check-out at"
    }
    AutoCompletionInput {
        id: input
        anchors {
            top: text.bottom
            left: parent.left
            right: parent.right
            margins: 8
        }
        listArea: listPlaceholder

        selected: true

        delegate: ListItem {
            width: parent.width
            ListItemXLabel {
                anchors {
                    left: parent.paddingItem.left
                    right: parent.paddingItem.right
                    verticalCenter: parent.paddingItem.verticalCenter
                }
                text: modelData.title
                highlightColor: "#BBB"
                highlightText: input.text
            }

            onClicked: {
                confirmation.icon = "../../../images/ticketing/dialog-tap.png"
                confirmation.stationId = modelData.id
                confirmation.open();
            }
        }

        function updateResults() {
            setResults(input.inputText.length
                       ? App.ticketing.findStations(inputText)
                       : App.ticketing.getStations()
                   );
        }
    }

    Rectangle {
        id: listPlaceholder
        anchors {
            top: input.bottom
            topMargin: 8
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }

        color: "#f1f1f1"
    }

    QueryDialog {
        id: confirmation

        property string stationId

        titleText: "Checkout confirmation"
        message: qsTrId("Do you want to checkout at <b>%1</b> ?")
                 .arg(App.ticketing.getStationNameForId(stationId))
        acceptButtonText: "Checkout"
        rejectButtonText: "Cancel"
        onAccepted: {
            selectedStationId = stationId;
            pageStack.pop();
        }
    }

}
