import QtQuick 1.0

import com.nokia.pt 1.0

import "ApplicationModel.js" as App
import "../qtcomponents"
import "../components"

Page {
    id: ttpage
    objectName: "transportTypeFilterPage"

    title: qsTrId("qtn_pt_ttfilterpage_title"); // "Filter settings"

    property variant filter: {}
    property variant metaInfo: []
    property variant result

    signal closed

    onStatusStrChanged: {
        if ("Activating" === statusStr) {
            app.analytics.logEvent("TransportTypeFilter");
        }
    }

    Flickable {
        anchors.fill: parent
        contentHeight: col.height
        Column {
            id: col
            width: parent.width

            ViewHeading {
                contentHeight: texts.paintedHeight
                ViewHeadingText {
                    id: texts
                    anchors {
                        left: parent.paddingItem.left;
                        right: parent.paddingItem.right;
                        verticalCenter: parent.paddingItem.verticalCenter
                    }
                    text: qsTrId("qtn_pt_ttfilterpage_select_transport"); // "Select the transport type for your journey"
                }
            }

            Repeater {
                // fill the model with text labels and sort alphabetically
                function prepareModel(model) {
                    model.forEach(function(item) {
                        item.text = qsTrId("qtn_pt_ttdropdown_transportmode_" + item.code);
                    });
                    return model.sort(function(a, b) { return a.text.localeCompare(b.text); });
                }

                model: prepareModel(metaInfo)

                delegate: ListItem {
                    id: item
                    Image {
                        id: icon
                        anchors.left: parent.left
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.leftMargin: 18
                        source: modelData.iconUri
                        width: 34
                        asynchronous: true
                    }

                    CheckBox {
                        id: checkbox
                        anchors {
                            right: parent.right
                            rightMargin: 4
                            verticalCenter: parent.verticalCenter
                        }
                        checked: isSelected(filter, modelData.code);
                        Component.onCompleted: clicked.connect(parent.clicked);
                    }

                    Text {
                        anchors {
                            left: icon.right
                            leftMargin: 18
                            right: checkbox.left
                            rightMargin: 4
                            verticalCenter: parent.verticalCenter
                        }
                        text: modelData.text
                        font: item.style.font
                        color: item.style.color
                    }

                    onClicked: {
                        var copy = filter;
                        checkbox.checked = copy[modelData.code] = !copy[modelData.code];
                        filter = copy;
                    }

                    function isSelected(filter, code) {
                        return !!filter[code];
                    }
                }
            }
        }
    }

    tools: ToolBarLayout {

        BackToolButton {
            onClicked: {
                result = false;
                closed();
            }
        }

        ToolIcon {
            objectName: "okBtn"
            iconId: "toolbar-done"
            enabled: isSomeSelected(filter)
            onClicked: {
                result = true;
                closed();
                pageStack.pop();
            }

            function isSomeSelected(filter) {
                for (var key in filter) { if (filter[key]) return true; }
                return false;
            }
        }
    }

    Component.onCompleted: {
        // dynamic translations has to be announced via QT_TRID_NOOP
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_0");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_1");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_2");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_3");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_4");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_5");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_6");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_7");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_8");
        QT_TRID_NOOP("qtn_pt_ttdropdown_transportmode_9");
    }
}


