import QtQuick 1.0

import "../ApplicationModel.js" as App

import com.nokia.pt 1.0

Item {
    id: currentPosition

    signal positionChanged
    signal reverseGeoCodeDone(variant address)

    property bool isSearching: true
    property bool notAvailable: true
    property real lastValidGps
    property bool enabled: System.appInForeground

    property alias method: gps.method
    property alias accuracy: gps.accuracy

    state: isSearching ? "searching" : (notAvailable ? "notavailable" : "valid")

    function triggerGpsSearch() {
        if (!isSearching) {
            gpsStart();
        }
    }

    function gpsStart() {
//        print("GPSXXXX: Started Position Search");
        isSearching = true;
        gps.active = true;
        gpsNotAvailableTimer.restart();
    }

    function gpsStop() {
//        print("GPSXXXX: Stopped Position Search");
        isSearching = false;
        gps.active = false;
    }

    property QtObject location: PtLocation {
        latitude: 0
        longitude: 0
        source: "currentPosition"
        title: qsTrId("qtn_pt_autocompletion_currentposition_no_address") // "Current Position"
    }

    function reverseGeoSearch() {
        if (App.queries.revGeoCode) {
            App.queries.revGeoCode.cancel();
            App.queries.revGeoCode.destroy();
            delete App.queries.revGeoCode;
        }

        var query = Search.reverseGeoCode(location.latitude, location.longitude);
        query.finished.connect(function(error, address) {
                                   // TODO retry
                                   if (error === QueryResult.NoError) {
                                       location.setAddress(address);
                                       currentPosition.reverseGeoCodeDone(address);
                                       console.log("reverse geo search finished:", App.serialize(address));
                                   } else {
                                       console.error("reverse geo search failed:", error);
                                   }

                                   App.queries.revGeoCode.destroy();
                                   delete App.queries.revGeoCode;
                               });

         App.queries.revGeoCode = query;
    }

    onEnabledChanged: {
        if (!enabled && gpsUpdateTimer.running) {
            gpsUpdateTimer.stop();
        }
        if (enabled && !isSearching) {
            gpsStart();
        }
    }

    Timer {
        id: gpsUpdateTimer
        // update gps every minute
        interval: 60000
        repeat: false
        triggeredOnStart: false
        onTriggered: {
            gpsStart();
        }
    }

    Timer {
        id: gpsNotAvailableTimer
        interval: gpsUpdateTimer.interval - 1
        onTriggered: {
            notAvailable = true;
        }
    }

    PeriodicPositionSource {
        id: gps
        active: true
        updateInterval: 60000

        onPositionChanged: {
            gpsNotAvailableTimer.stop();

            if (null !== position.coordinate.latitude
                    || null !== position.coordinate.longitude) {
                console.log("GPSXXXX-Update: ", JSON.stringify(position));

                gps.active = false;

                if (position.coordinate.latitude !== location.latitude ||
                    position.coordinate.longitude !== location.longitude) {
                    location.latitude = position.coordinate.latitude || 0;
                    location.longitude = position.coordinate.longitude || 0;
                    reverseGeoSearch();
                    currentPosition.positionChanged();

                    App.settings.lastKnownPosition = {
                        date: lastValidGps,
                        latitude: position.coordinate.latitude,
                        longitude: position.coordinate.longitude
                    }
                    App.saveSettings();
                }
            } else {
                console.error("GPSXXXX-Update.error:", "Invalid coordinates received ->", JSON.stringify(position));
            }

            lastValidGps = Date.now();
            notAvailable = false;
            isSearching = false;

            gpsUpdateTimer.restart();
        }
    }

    Component.onCompleted: {
        var lastPos = App.settings.lastKnownPosition;
        if (lastPos) {
            lastValidGps = lastPos.date;
            location.latitude = lastPos.latitude;
            location.longitude = lastPos.longitude;
        }
        gpsStart();
    }
}
