import QtQuick 1.0
import "../ApplicationModel.js" as App

QtObject {
    id: model

    signal added(bool sticky)
    signal removed(bool sticky)

    function add(loc, name, sticky) {
        _load();
        if (!loc || find(loc)) {
            console.error("favorites.add was called with item to null or an existing favorite!", loc);
            return;
        }
        App._favs[_mkKey(loc)] = {
            $location: loc,
            $sticky: sticky,
            $lastUse: Date.now()
        }
        loc.parent = model; // set parent to application
        loc.favoriteName = name || loc.favoriteName || loc.title;
        _save();
        added(sticky);
        return loc;
    }

    function remove(fav, newOwner) {
        _load();
        var key = _mkKey(fav);
        if (App._favs[key]) {
            var sticky = App._favs[key].$sticky;
            delete App._favs[key];
            if (undefined !== newOwner) {
                fav.parent = newOwner;
            }
            fav.favoriteName = "";
            _save();
            removed(sticky);
            return true;
        } else {
            console.error("favorites.remove: favorite not found");
        }
    }

    function find(loc, sticky) {
        _load();
        var key = _mkKey(loc);
        return App._favs[key] && (!sticky || (sticky && App._favs[key].$sticky)) && App._favs[key].$location;
    }

    function get(sticky) {
        _load();
        var f = [];
        for (var key in App._favs) {
            if (!sticky || (sticky && App._favs[key].$sticky)) {
                f.push(App._favs[key]);
            }
        }
        return f.sort(function(a, b) {
                return (a.$lastUse || 0) - (b.$lastUse || 0);
            }).map(function(fav) {
                return fav.$location;
            });
    }

    function clear() {
        App._favs = {};
        _save();
    }

    function use(loc) {
        _load();
        var key = _mkKey(loc);
        if (App._favs[key]) {
            App._favs[key].$lastUse = Date.now();
            _save();
        }
    }

    function _load() {
        if (!App._favs) {
            var fav,
                f = App.deserialize(App.storage.get("Favorites_1.0") || "[]");
            App._favs = {};
            f.forEach(function(item) {
                          fav = _convert(item);
                          // don't load buggy favorites
                          if (!fav.$location.title && !fav.$location.favoriteName && !fav.$location.latitude && !fav.$location.longitude)
                              return;
                          // force a favorite name
                          fav.$location.favoriteName = fav.$location.favoriteName || fav.$location.displayName || fav.$location.title;
                          fav.parent = model;
                          App._favs[_mkKey(fav.$location)] = fav;
                      });
            console.log("favorites loaded:", get().length);
        }
    }

    function _save() {
        var f = [];
        for (var key in App._favs) {
            f.push(App._favs[key]);
        }
        App.storage.set("Favorites_1.0", App.serialize(f));
        console.log("favorites saved:", get().length);
    }

    function _mkKey(loc) {
        return loc.title + "#" + loc.latitude + "#" + loc.longitude;
    }

    function _convert(fav) {
        if (fav.$location) { // new fav structure
            fav.$location = System.deserialize(fav.$location, "favorites");
        } else { // old fav structure
            fav = {
                $location: System.deserialize(fav, "favorites")
            };
        }
        return fav;
    }
}
