import QtQuick 1.0
import "../ApplicationModel.js" as App

QtObject {
    id: model

    function add(loc) {
        if (loc.source.indexOf("currentPosition") > -1 || (!loc.longitude && !loc.latitude)) {
            return;
        }

        _load();
        var _internalItem = _getInternalItem(loc);
        loc.parent = model; // take over ownership
        if (_internalItem) {
            _internalItem.$lastUse = Date.now();
        } else {
//            loc.parent = model; // take over ownership
            App._history.push({
                value: loc,
                $lastUse: Date.now()
            });
        }
        App._history.sort(function(a, b) {
                              return b.$lastUse - a.$lastUse;
                          });
        // limit to 30 entries (removed items are memory leaks but no need to fix now)
        App._history.splice(30);
        // TODO
        _save();
    }

    function get() {
        _load();
        return App._history.map(function(loc) {
                                    return loc.value;
                                });
    }

    function clear() {
        App._history = [];
        _save();
    }

    function contains(loc) {
        _load();
        // indexOf doesn't work :(
        for (var i = 0, l = App._history.length; i < l; i++) {
            if (loc == App._history[i].value) return true;
        }
    }

    function _load() {
        if (!App._history) {
            App._history = App.deserialize(App.storage.get("SearchHistory_1.0") || "[]");
            App._history.forEach(function(loc) {
                loc.value = System.deserialize(loc.value, "history");
                loc.value.favoriteName = ""; // make sure no favorite artifacts are loaded
                loc.value.parent = model;
                // migration step, keep the order of old history items (old means ordered by usage instead of last usage) Can be removed after some revisions.
                loc.$lastUse = loc.$lastUse || loc.counter;
                delete loc.counter;
            });
            console.log("history locations loaded:", get().length);
        }
    }

    function _save() {
        App.storage.set("SearchHistory_1.0", App.serialize(App._history));
        console.log("history locations saved:", get().length);
    }

    function _getInternalItem(loc) {
        _load();
        for (var i = 0, item; (item = App._history[i]); i++) {
            if (item.value == loc || item.value.displayName == loc.displayName) {
                return item;
            }
        }
    }

}
