import QtQuick 1.0

Rectangle {
    id: listItem

    property bool interactive: true
    property bool enabled: true
    property bool ignoreMouseEvents: false
    property bool subItemIndicator: false
    property bool brightBackground: true
    property alias paddingItem: paddingItem

    default property alias myChildren: childItems.children
    property alias clickAreaAnchors: area.anchors

    signal clicked
    signal longpress

    height: 90
    width: parent ? parent.width : 100
    color: "#efefef"

    Rectangle {
        height: 1
        width: parent.width
        y: 0
        color: Qt.tint(listItem.color, interactive ? "#40000000" : "#15000000")
    }

    Rectangle {
        height: 1
        width: parent.width
        y: parent.height
        color: Qt.tint(listItem.color, interactive ? "#40000000" : "#15000000")
    }

    Item {
        id: childItems
        anchors.fill: parent

        Item {
            id: paddingItem
            anchors.fill: parent
            anchors.margins: 5
        }


        states: [State {
                name: "pressed"
                PropertyChanges {
                    target: listItem
                    color: "#cdcdcd"
                }
                PropertyChanges {
                    target: childItems
                    opacity: 0.7
                }
            },State {
                name: "disabled"
                when: !listItem.enabled
                PropertyChanges {
                    target: listItem
                    color: "#eaeaea"
                }
                PropertyChanges {
                    target: childItems
                    opacity: 0.5
                }
            }]
    }

    MouseArea {
        id: area
        anchors.fill: parent
        enabled: listItem.enabled && listItem.interactive && (!ignoreMouseEvents)

        onPressAndHold: {
            listItem.longpress();
        }

        onPressed: {
            childItems.state = "pressed";
        }

        onReleased:  {
            childItems.state = "";
        }

        onHoveredChanged: {
            childItems.state = "";
        }

        onClicked: {
            clickAnim.stop();
            childItems.state = "";
            clickAnim.start();
        }
    }

    ParallelAnimation {
        id: clickAnim

        PropertyAnimation {
            target: childItems
            property: "opacity"
            from: 0.7; to: 1.0;
            easing.type: "OutQuad"
            duration: 250
        }

        SequentialAnimation {
            PropertyAnimation {
                target: listItem
                property: "color"
                from: "#cdcdcd"; to: "#fffeff";
                easing.type: "InQuad"
                duration: 250
            }
            ScriptAction {
                script: { listItem.clicked(); }
            }
            PropertyAnimation {
                target: listItem
                property: "color"
                from: "#fffeff"; to: "#efefef";
                easing.type: "InQuad"
                duration: 250
            }
        }
    }
}
